/**********************************************************************
 * Copyright (c) 2003 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
*
 * Contributors:
 *    IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.monitor.core;

import java.util.Date;
/**
 * 
 */
public interface IRequest {
	public static final byte TRANSPORT = 1;
	public static final byte CONTENT = 2;
	public static final byte ALL = 3;

	/**
	 * Return the type of the request.
	 * 
	 * @return org.eclipse.monitor.core.IType
	 */
	public IProtocolAdapter getType();

	/**
	 * Return the date/time of this request.
	 *
	 * @return java.util.Date
	 */
	public Date getDate();

	/**
	 * Returns the local port.
	 *
	 * @return int
	 */
	public int getLocalPort();

	/**
	 * Returns the remote host.
	 *
	 * @return java.lang.String
	 */
	public String getRemoteHost();

	/**
	 * Returns the remote port.
	 *
	 * @return int
	 */
	public int getRemotePort();

	/**
	 * Returns the request as a byte array.
	 *
	 * @return byte[]
	 */
	public byte[] getRequest(byte type);

	/**
	 * Returns the response as a byte array.
	 *
	 * @return byte[]
	 */
	public byte[] getResponse(byte type);

	/**
	 * Returns the response time in milliseconds.
	 *
	 * @return long
	 */
	public long getResponseTime();

	/**
	 * Returns a label for this request.
	 *
	 * @return java.lang.String
	 */
	public String getLabel();

	/**
	 * 
	 */
	public void addProperty(String key, Object value);

	/**
	 * 
	 */
	public String getStringProperty(String key);

	/**
	 * 
	 */
	public Integer getIntegerProperty(String key);

	/**
	 * 
	 */
	public Object getObjectProperty(String key);
	
	/**
	 * 
	 */
	public void fireChangedEvent();
}