/**********************************************************************
 * Copyright (c) 2003 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
*
 * Contributors:
 *    IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.monitor.ui.internal.view;

import java.util.List;

import org.eclipse.core.runtime.IConfigurationElement;

import org.eclipse.monitor.core.IContentFilter;
import org.eclipse.monitor.core.IRequest;
/**
 * Manager interface for TCP/IP request and response message viewers
 */
public interface IViewerManager {
	/**
	 * Displays the HTTP header viewers if they are hidden.
	 * If the viewers are not hidden, do nothing.
	 */
	//public void showHeader();
	
	/**
	 * Hides the HTTP header viewers if they are showing.
	 * If the viewers are already hidden, do nothing.
	 */
	//public void hideHeader();
	
	/**
	 * Set whether or not to show HTTP header details
	 * @param b boolean
	 */
	public void setDisplayHeaderInfo(boolean b);
	
	/**
	 * Returns whether or not HTTP header details is showing
	 * @return boolean
	 */
	public boolean getDisplayHeaderInfo();
	
	/**
	 * Show the TCP/IP request message in a parent Composite
	 * @param rr org.eclipse.tcpip.monitor.internal.RequestResponse
	 * @param parent org.eclipse.swt.widgets.Composite
	 */
	public void setRequest(IRequest rr);
	
	/**
	 * Returns an array of the available TCP/IP request viewer ids
	 * @return java.lang.String[]
	 */
	public List getRequestViewers();
	
	/**
	 * Returns an array of the available TCP/IP response viewer ids
	 * @return java.lang.String[]
	 */
	public List getResponseViewers();
	
	/**
	 * Set the TCP/IP request message viewer
	 * @param id java.lang.String
	 */
	public void setRequestViewer(IConfigurationElement element);
	
	/**
	 * Set the TCP/IP response message viewer
	 * @param id java.lang.String
	 */
	public void setResponseViewer(IConfigurationElement element);
	
	public void addFilter(IContentFilter filter);
	
	public void removeFilter(IContentFilter filter);
}