/**
 * <copyright>
 *
 * Copyright (c) 2002-2003 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 *   IBM - Initial API and implementation
 *
 * </copyright>
 */
package org.eclipse.soap.validate.wsi;
                    
import org.eclipse.core.runtime.IPluginDescriptor;
import org.eclipse.ui.plugin.AbstractUIPlugin;

import java.util.ResourceBundle;

/**
 * WSIValidatePlugin is a plugin that integrates with the Eclipse platform UI. 
 * 
 * @author David Lauzon, IBM
 */

public class WSIValidatePlugin extends  AbstractUIPlugin
{
  /**
   * The singleton.
   */
  protected static WSIValidatePlugin instance;                
  protected ResourceBundle resourcebundle;

  /**
   * Constructor.
   * @param descriptor an IPluginDescriptor object.
   */
  public WSIValidatePlugin(IPluginDescriptor descriptor)
  {
    super(descriptor);
    instance = this;
    resourcebundle = descriptor.getResourceBundle();
  }    

  /**
   * Returns the singleton. (Based on the Singleton Pattern).
   * @return the singleton.
   */
  public static WSIValidatePlugin getInstance()
  {
    return instance;
  }

  /**
   * This gets the string resource.
   * @param key a key associated witha string resource.
   * @return the string resource.
   */
  public String getString(String key)
  {
    return getResourceBundle().getString(key);
  } 

  /**
   * Convience API.     
   * This gets the string resource based on the key.
   * @param key key associated witha string resource.
   * @return the string resource associated with the given key.
   */
  public static String getWSIString(String key)
  {
    return instance.getString(key);
  }

  /**
   * Get resource bundle.
   * @return resource bundle.
   */
  public ResourceBundle getResourceBundle()
  {
    return resourcebundle;
  }
}
