/**
 * <copyright>
 *
 * Copyright (c) 2002-2003 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 *   IBM - Initial API and implementation
 *
 * </copyright>
 */
package org.eclipse.wsdl.validate.wsi;

import org.eclipse.wsdl.validate.wsi.internal.CheckWSIImpl;

/**
 * An abstract class to be extended to determine the WS-I
 * conformance level to run the validator with.
 * 
 * @author Lawrence Mandel (lmandel@ca.ibm.com)
 */
public abstract class CheckWSI
{
  public static final int WSI_REQUIRE = 0;
  public static final int WSI_SUGGEST = 1;
  public static final int WSI_IGNORE = 2;

  protected static CheckWSI instance = null;
  protected static String checkWSIClass = null;
  protected static ClassLoader classLoader = null;
  /**
   * CheckWSIRegister
   * Holds the ICheckWSI object.
   */
  protected CheckWSI()
  {
  }

  /**
   * Return the one and only instance of the WS-I check.
   * 
   * @return The one and only instance of the WS-I check.
   */
  public static CheckWSI getInstance()
  {
    if (instance == null)
    {
      if (checkWSIClass != null && classLoader != null)
      {
        try
        {
          Class catalogClass = CheckWSI.classLoader != null
              ? CheckWSI.classLoader.loadClass(checkWSIClass)
              : Class.forName(checkWSIClass);
          instance = (CheckWSI)catalogClass.newInstance();
        }
        catch (Exception e)
        {
          instance = new CheckWSIImpl();
        }
      }
      else
      {
        instance = new CheckWSIImpl();
      }
    }
    return instance;
  }

 /**
  * Set the class that will be used to determine the WS-I conformance level.
  * 
  * @param checkWSIClass The name of the class.
  * @param classLoader The class loader to use to load the class.
  */
  public static void setCheckWSI(String checkWSIClass, ClassLoader classLoader)
  {
    CheckWSI.checkWSIClass = checkWSIClass;
    CheckWSI.classLoader = classLoader;
  }

 /**
  * Check the conformance level for the given file.
  * 
  * @param fileuri The URI of the file we are going to check.
  * @return The conformance level to run.
  */
  public abstract int checkWSI(String fileuri);
}
