/**
 * <copyright>
 *
 * Copyright (c) 2002-2003 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 *   IBM - Initial API and implementation
 *
 * </copyright>
 */
package org.eclipse.wsdl.validate.wsi.internal;

import java.util.ResourceBundle;

import org.eclipse.core.runtime.IConfigurationElement;
import org.eclipse.core.runtime.IExtensionPoint;
import org.eclipse.core.runtime.IPluginDescriptor;
import org.eclipse.core.runtime.IPluginRegistry;
import org.eclipse.core.runtime.Platform;
import org.eclipse.ui.plugin.AbstractUIPlugin;
import org.eclipse.wsdl.validate.wsi.CheckWSI;

/**
 * The main plugin file. This plugin provides WS-I conformance checks for the WSDL Validator.
 * 
 * @author Lawrence Mandel (lmandel@ca.ibm.com)
 */
public class WSDLWSIValidatePlugin extends AbstractUIPlugin
{
  protected final String PLUGIN_PROPERTIES = "validatewsi";

  protected static WSDLWSIValidatePlugin instance;
  protected ResourceBundle resourcebundle = null;

  /**
   * Constructor.
   */
  public WSDLWSIValidatePlugin(IPluginDescriptor descriptor)
  {
    super(descriptor);
    instance = this;
    resourcebundle = ResourceBundle.getBundle(PLUGIN_PROPERTIES);
    new WSIPreferencePluginRegistryReader().readRegistry();
  }

  /**
   * Returns the instance of this plugin object.
   * 
   * @return The instance of this plugin object.
   */
  public static WSDLWSIValidatePlugin getInstance()
  {
    return instance;
  }
  
  /**
   * Returns the resource bundle for this plugin.
   * 
   * @return The resource bundle for this plugin.
   */
  public ResourceBundle getResourceBundle()
  {
    return resourcebundle;
  }
}

/**
 * This class reads the plugin manifests and registers each WSDLExtensionValidator
 *  xmlvalidator
 */
class WSIPreferencePluginRegistryReader
{
	protected static final String PLUGIN_ID = "org.eclipse.wsdl.validate.wsi";
	protected static final String EXTENSION_POINT_ID = "wsipreference";
	protected static final String TAG_NAME = "wsipreference";
	protected static final String ATT_CLASS = "class";
	protected String pluginId, extensionPointId;

	/**
	 * read from plugin registry and parse it.
	 */
	public void readRegistry()
	{
		IPluginRegistry pluginRegistry = Platform.getPluginRegistry();
		IExtensionPoint point = pluginRegistry.getExtensionPoint(PLUGIN_ID, EXTENSION_POINT_ID);
		if (point != null)
		{
			IConfigurationElement[] elements = point.getConfigurationElements();
			for (int i = 0; i < elements.length; i++)
			{
				readElement(elements[i]);
			}
		}
	}

	/**
	 * readElement() - parse and deal with an extension like:
	 *
	 * <extension point="com.ibm.etools.validate.wsdl.WSDLExtensionValidator"
	 *            id="soapValidator"
	 *            name="SOAP Validator">>
	 *   <validator>
	 *        <run class=" com.ibm.etools.validate.wsdl.soap.SOAPValidator"/>
	 *   </validator>
	 *   <attribute name="namespace" value="http://schemas.xmlsoap.org/wsdl/soap/"/>
	 * </extension>
	 */
	protected void readElement(IConfigurationElement element)
	{
		if (element.getName().equals(TAG_NAME))
		{
			String wsiRegisterClass = element.getAttribute(ATT_CLASS);

			if (wsiRegisterClass != null)
			{
				try
				{
					// modified to resolve certain situations where the plugin has not been initialized
					ClassLoader pluginLoader =
						element.getDeclaringExtension().getDeclaringPluginDescriptor().getPluginClassLoader();
					//					ClassLoader pluginLoader =
					//						element.getDeclaringExtension().getDeclaringPluginDescriptor().getPlugin().getClass().getClassLoader();
					CheckWSI.setCheckWSI(wsiRegisterClass, pluginLoader);
				}
				catch (Exception e)
				{
					System.out.println("Error loading extension functionality class. " + e);
				}
			}
		}
	}
}
