/**
 * <copyright>
 *
 * Copyright (c) 2002-2003 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 *   IBM - Initial API and implementation
 *
 * </copyright>
 */
package org.eclipse.wsdl20;

/**
 * ValidatableElement
 * An interface representing an element that can be validated. Elements that can
 * be validated are required to know their location. What file they're in and the
 * line and column number in the file.
 * 
 * @author Lawrence Mandel, IBM
 */
public interface ValidatableElement
{
  /**
   * getLocationURI
   * Return the URI of the file the element is located in.
   * 
   * @return the URI of the file the element is located in
   */
  public String getLocationURI();
	
  /**
   * getLine
   * Return the line in the file that the element is located at.
   * 
   * @return an int with the line this element is located at
   */
  public int getLine();
  
  /**
   * getColumn
   * Return the column in the file that the element is located at.
   * 
   * @return an int with the column this element is located at
   */
  public int getColumn();
}
