/**
 * <copyright>
 *
 * Copyright (c) 2002-2003 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 *   IBM - Initial API and implementation
 *
 * </copyright>
 */
package org.eclipse.wsdl20.model;

/**
 * This interface represents the binding element information item in
 * the WSDL 2.0 specification's abstract model (section 2.8). A binding contains
 * an optional Interface
 * zero or more BindingOperations
 * zero or more Features
 * zero or more Properties
 * 
 * The XML representation of a binding is:
 * <binding
 *      name="xs:NCName" 
 *      interface="xs:QName"? >
 *  <documentation />?
 *  [ <feature /> | <property /> | <operation /> ]*
 * </binding>
 * 
 * @author Lawrence Mandel, IBM
 */
public interface Binding extends ElementInfoItem
{
  /**
   * Returns the Interface defined for this binding or null
   * if no interface is defined.
   * 
   * @return The Interface defined for the binding.
   */
  public Interface getInterface();

  /**
   * Returns the set of operations for this binding.
   * 
   * @return An array of BindingOperations.
   */
  public BindingOperation[] getBindingOperations();

  /**
   * Returns the set of features for this binding.
   * 
   * @return An array of Features.
   */
  public Feature[] getFeatures();

  /**
   * Returns the set of properties for this binding.
   * 
   * @return An array of Properties.
   */
  public Property[] getProperties();
}
