/**
 * <copyright>
 *
 * Copyright (c) 2002-2003 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 *   IBM - Initial API and implementation
 *
 * </copyright>
 */
package org.eclipse.wsdl20.model;

/**
 * This interface represents a binding fault reference element information
 * item from the WSDL 2.0 specification's abstract model (section 2.11). A 
 * binding fault reference can be an infault or outfault.
 * 
 * The XML representation of a BindingFaultReference is one of:
 * <infault
 *   name="xs:NCName"
 *   messageReference="xs:NCName" >
 *  <documentation />?
 * </infault>
 * <outfault
 *   name="xs:NCName"
 *   messageReference="xs:NCName" >
 *  <documentation />?
 * </outfault>
 * 
 * @author Lawrence Mandel, IBM
 */
public interface BindingFaultReference extends ElementInfoItem
{
  /**
   * The message within the operation for which this fault relates to.
   * 
   * @return The message in the operation.
   */
  public MessageReference getMessageReference();

  /**
   * If the local name of this element information item is infault
   * the returns 'in' or if it's outfault returns 'out'.
   * 
   * @return in or out based on the local name.
   */
  public String getDirection();
}
