/**
 * <copyright>
 *
 * Copyright (c) 2002-2003 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 *   IBM - Initial API and implementation
 *
 * </copyright>
 */
package org.eclipse.wsdl20.model;

/**
 * This interface represents a binding message reference element information
 * item from the WSDL 2.0 specification's abstract model (section 2.10). A 
 * binding message reference can be an input, output, infault or outfault.
 * 
 * The XML representation of a binding message reference is one of:
 * <input
 *   name="xs:NCName"? >
 *  <documentation />?
 * </input>
 * <output
 *   name="xs:NCName"? >
 *  <documentation />?
 * </output>
 * 
 * @author Lawrence Mandel, IBM
 */
public interface BindingMessageReference extends ElementInfoItem
{
	
  /**
   * The message within the operation for which binding details are being specified.
   * 
   * @return The message reference in the operation.
   */
  public MessageReference getMessage();
  
  /**
   * If the local name of this element information item is input
   * the returns 'in' or if it's output returns 'out'.
   * 
   * @return in or out based on the local name.
   */
  public String getDirection();
}
