/**
 * <copyright>
 *
 * Copyright (c) 2002-2003 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 *   IBM - Initial API and implementation
 *
 * </copyright>
 */
package org.eclipse.wsdl20.model;

/**
 * This interface represents a binding operation from the WSDL 2.0 specification's
 * abstract model (section 2.9). A binding operation can have 
 * zero or more binding message reference components (that are input, output, infault, outfault)
 * zero or more features
 * zero or more properties
 * 
 * The XML representation of a binding operation is:
 * <operation
 *   name="xs:QName" >
 *  <documentation />?
 *  [ <feature /> | <property /> | 
 *   [ <input /> | <output /> | <infault /> | <outfault /> ]+
 *  ]*
 * </operation>
 * 
 * @author Lawrence Mandel, IBM
 */
public interface BindingOperation extends ElementInfoItem
{
  /**
   * Returns any defined binding message reference components.
   * 
   * @return An array of BindingMessageReferences.
   */
  public BindingMessageReference[] getBindingMessageReferences();

  /**
   * Returns any defined binding fault reference components.
   * 
   * @return An array of BindingFaultReferences.
   */
  public BindingFaultReference[] getBindingFaultReferences();

  /**
  	* Returns any defined features.
  	* 
  	* @return An array of features.
  	*/
  public Feature[] getFeatures();

  /**
  	* Returns any defined properties.
  	* 
  	* @return An array of properties.
  	*/
  public Property[] getProperties();
}
