/**
 * <copyright>
 *
 * Copyright (c) 2002-2003 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 *   IBM - Initial API and implementation
 *
 * </copyright>
 */
package org.eclipse.wsdl20.model;

/**
 * An interface for the abstract definitions element information item in the WSDL 2.0 model
 * (section 2.1). A definitions element information item contains all other components in 
 * the WSDL 2.0 model. A definitinos element can contain:
 * zero or more imports
 * zero or more includes
 * zero or one types
 * zero or more interfaces
 * zero or more bindings
 * zero or more services
 * 
 * The XML representation of the definitions element information item is:
 * 
 * <definitions
 *    targetNamespace="xs:anyURI" >
 *   <documentation />?
 *   [ <import /> | <include /> ]*
 *   <types />?
 *   [ <interface /> | <binding /> | <service /> ]*
 * </definitions>
 *
 * @author Lawrence Mandel, IBM
 */
public interface Definitions extends ElementInfoItem
{

  /**
   * Returns a list of any imported WSDL documents.
   * 
   * @return An array of all the imported WSDL documents.
   */
  public Import[] getImports();

  /**
   * Returns a list of any included WSDL documents.
   * 
   * @return An array of all the included WSDL documents.
   */
  public Include[] getIncludes();

  /**
   * Returns a list of all the interface element information items (Interface)
   * specified for this definitions element information item.
   * 
   * @return An array of all the Interfaces defined.
   */
  public Interface[] getInterfaces();

  /**
   * Returns a list of all the binding element information items (Binding)
   * specified for this definitions element information item.
   * 
   * @return An array of all the Bindings defined.
   */
  public Binding[] getBindings();

  /**
   * Returns a list of all the service element information items (Service)
   * specified for this definitions element information item.
   * 
   * @return An array of all the Services defined.
   */
  public Service[] getServices();

  /**
   * Returns the optional types element information item.
   * 
   * @return An optional types elementInfoItem.
   */
  public Types getTypes();

}
