/**
 * <copyright>
 *
 * Copyright (c) 2002-2003 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 *   IBM - Initial API and implementation
 *
 * </copyright>
 */
package org.eclipse.wsdl20.model;

import javax.xml.namespace.QName;

/**
 * This interface represents an element information item from the 
 * WSDL 2.0 specification's abstract model. An element information item
 * contains:
 * one name
 * one target namespace
 * zero or more attribute information items
 * zero or more element information items
 * 
 * An element information item is not meant to be a concrete component in the
 * model in and of itself but rather is an abstract base item for every component
 * in the model.
 * 
 * @author Lawrence Mandel, IBM
 */
public interface ElementInfoItem
{

  /**
   * Returns the attribute information item for the name of this
   * element information item.
   * 
   * @return An AttributeInfoItem representing the name.
   */
  public String getName();

  /**
   * Return the qualified name for this element info item.
   * 
   * @return The qualified name for this element info item.
   */
  public QName getQName();
  
  /**
   * Returns the target namespace associated with this element information item.
   * 
   * @return A String with the target namespace.
   */
  public String getTargetNamespace();

  /**
   * Returns a list of any attribute information items specified for this
   * element information item.
   * 
   * @return An array of AttributeInfoItems.
   */
  public AttributeInfoItem[] getAttributeInfoItems();

  /**
   * Returns a list of any element information items specified for this
   * element information item.
   * 
   * @return An array of ElementInfoItems.
   */
  public ElementInfoItem[] getElementInfoItems();
}
