/**
 * <copyright>
 *
 * Copyright (c) 2002-2003 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 *   IBM - Initial API and implementation
 *
 * </copyright>
 */
package org.eclipse.wsdl20.model;

/**
 * This interface represents a fault reference in the WSDL 2.0 specification's
 * abstract model (section 2.5). A fault reference contains:
 * a name
 * a direction, either 'in' or 'out'
 * a set of message reference components
 * 
 * The XML representation of a fault reference is:
 * <infault
 *   name="xs:NCName" 
 *   messages="list of xs:QName" >
 *  <documentation />?
 * </infault>
 * <outfault
 *   name="xs:NCName" 
 *   messages="list of xs:QName" >
 *  <documentation />?
 * </outfault>
 * 
 * @author Lawrence Mandel, IBM
 */
public interface FaultReference extends ElementInfoItem
{
  /**
   * Returns the direction of this fault reference. If the reference name is
   * infault then 'in' and if it's outfault then 'out'.
   * 
   * @return in or out depending on the fault reference name.
   */
  public String getDirection();
  
  /**
   * Returns the message this fault message relates to in the message exchange of the
   * Interface operation.
   * 
   * @return A MessageReference containing the message the fault relates to.
   */
  public MessageReference getMessageReference();
  
  
  /**
   * Returns the message attribute information item that refers to an element declaration.
   * 
   * @return A represention if the message body.
   */
  public String getMessage();
  
}
