/**
 * <copyright>
 *
 * Copyright (c) 2002-2003 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 *   IBM - Initial API and implementation
 *
 * </copyright>
 */
package org.eclipse.wsdl20.model;


/**
 * This interface represents a feature in the WSDL 2.0 specification's 
 * abstract model (section 2.6). A feature describes an abstract 
 * functionality that deals with message exchange.
 * A feature contain:
 * a URI attribute information item
 * a required attribute information item (defaults to false)
 * 
 * The XML representation of a feature is:
 * <feature
 *   uri="xs:QName" 
 *   required="xs:boolean"? >
 *  <documentation />?
 * </feature>
 * 
 * @author Lawrence Mandel, IBM
 */
public interface Feature extends ElementInfoItem
{
  
  /**
   * Get the URI that defines this feature.
   * 
   * @return The URI that defines this feature.
   */
  public String getURI();
  
  /**
   * Returns if this feature is required. Defaults to false.
   * 
   * @return True if this feature is required, false otherwise.
   */
  public boolean isRequired();
  
  
  
}
