/**
 * <copyright>
 *
 * Copyright (c) 2002-2003 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 *   IBM - Initial API and implementation
 *
 * </copyright>
 */
package org.eclipse.wsdl20.model;

/**
 * This interface represents an import element information item in the
 * WSDL 2.0 specification's abstract model (section 4.2). An import
 * element information item allows the modularization of a WSDL 2.0
 * document. An import contains:
 * a required namespace
 * an optional location
 * 
 * The XML representation of an import is:
 * <import
 *   namespace="xs:anyURI" 
 *   location="xs:anyURI"? >
 *  <documentation />?
 * </import>
 * 
 * @author Lawrence Mandel, IBM
 */
public interface Import extends ElementInfoItem
{
  /**
   * Returns the namespace attribute information item specified for this import.
   * 
   * @return The imported namespace.
   */
  public String getNamespace();
  
  /**
   * Returns the location attribute information item if specified, null otherwise.
   * 
   * @return The location of this import.
   */
  public String getLocation();
}
