/**
 * <copyright>
 *
 * Copyright (c) 2002-2003 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 *   IBM - Initial API and implementation
 *
 * </copyright>
 */
package org.eclipse.wsdl20.model;

/**
 * This interface represents an interface element information item from
 * the WSDL 2.0 specification's abstract model (section 2.2). An interface
 * describes a set of messages that a service sends and receives. An interface
 * element information item contains:
 * an optional extends attribute information item
 * an optional style default attribute information item
 * zero or more operation element information items
 * zero or more feature element information items
 * zero or more property element information items
 * 
 * The XML representation of an interface is:
 * <interface
 *   name="xs:NCName" 
 *   extends="list of xs:QName"?
 *   styleDefault="xs:anyURI"? >
 *  <documentation />?
 *  [ <operation /> | <feature /> | <property /> ]*
 * </interface>
 * 
 * @author Lawrence Mandel, IBM
 */
public interface Interface extends ElementInfoItem
{

  /**
   * Returns a set of extended interfaces from the extends attribute information item
   * plus any extended interfaces from the interfaces in the list.
   * 
   * @return An array of Interfaces.
   */
  public Interface[] getExtendedInterfaces();

  /**
   * Retruns the default style for this interface.
   * 
   * @return An AttributeInfoItem with the default style.
   */
  public String getStyleDefault();

  /**
   * Returns a set of the operations for this interface.
   * 
   * @return An array of InterfaceOperations.
   */
  public InterfaceOperation[] getOperations();

  /**
   * Returns a set of the features for this interface.
   * 
   * @return An array of Features.
   */
  public Feature[] getFeatures();

  /**
   * Returns a set of the properties for this interface.
   * 
   * @return An array of Properties.
   */
  public Property[] getProperties();

}
