/**
 * <copyright>
 *
 * Copyright (c) 2002-2003 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 *   IBM - Initial API and implementation
 *
 * </copyright>
 */
package org.eclipse.wsdl20.model;

/**
 * This interface represents the interface operation element information item
 * from the WSDL 2.0 specification's abstract model (section 2.3). An interface
 * operation contains:
 * a required name attribute information item
 * a required message exchange pattern attribute information item
 * an optional style attribute information item
 * zero or more message reference element information items (input, output)
 * zero or more fault reference element information items (infault, outfault)
 * zero or more feature element information items
 * zero or more property element information items
 * 
 * The XML representation of an interface operation is:
 * <operation
 *   name="xs:NCName" 
 *   pattern="xs:anyURI"
 *   style="xs:anyURI"? >
 *  <documentation />?
 *  [ <feature /> | <property /> | 
 *   [ <input /> | <output /> | <infault /> | <outfault /> ]+
 *  ]*
 * </operation>
 * 
 * @author Lawrence Mandel, IBM
 */
public interface InterfaceOperation extends ElementInfoItem
{
	
  /**
   * Returns all the message references (input, output) specified for this operation.
   * 
   * @return An array of MessageReferences.
   */
  public MessageReference[] getMessageReferences();

  /**
   * Returns all the fault references (infault, outfault) specified for this operation.
   * 
   * @return An array of FaultReferences.
   */
  public FaultReference[] getFaultReferences();

  /**
   * Returns the URI for the message exchange pattern for this operation.
   * 
   * @return The URI of the message exchange pattern.
   */
  public String getMessageExchangePattern();

  /**
   * Returns a URI that specifies the rules used to construct the body of the messages.
   * 
   * @return The URI for the style.
   */
  public String getStyle();

  /**
   * Returns the set of features for this operation.
   * 
   * @return An array of Features.
   */
  public Feature[] getFeatures();

  /**
   * Returns the set of properties for this operation.
   * 
   * @return An array of Properties.
   */
  public Property[] getProperties();

}
