/**
 * <copyright>
 *
 * Copyright (c) 2002-2003 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 *   IBM - Initial API and implementation
 *
 * </copyright>
 */
package org.eclipse.wsdl20.model;

/**
 * This interface represents a message reference element informatio item
 * from the WSDL 2.0 specification's abstract model (section 2.4). 
 * A message reference associates XML element declarations with messages
 * used in interface operations.
 * A message reference contains:
 * a name attribute information item (either input or output)
 * an optional message reference attribute information item (identifies the role)
 * an optional headers attribute information item
 * 
 * The XML representation of a message reference element information item is one of:
 * <input
 *   messageReference="xs:NCName"? 
 *   body="xs:QName"?
 *   headers="list of xs:QName"? >
 *  <documentation />?
 * </input>
 * <output
 *   messageReference="xs:NCName"?
 *   body="xs:QName"?
 *   headers="list of xs:QName"? >
 *  <documentation />?
 * </output>
 * 
 * @author Lawrence Mandel, IBM
 */
public interface MessageReference extends ElementInfoItem
{
  /**
   * Returns the role this message reference plays in the operation.
   * 
   * @return The role of this message reference.
   */
  public String getMessageReference();
  
  /**
   * Returns the direction of the message reference. The direction is based on the
   * local name. If the name is input returns 'in' and if it's output returns 'out'.
   * 
   * @return 'in' if name is input, 'out' if name is output.
   */
  public String getDirection();
  
  /**
   * Returns the message that refers to an element declaration.
   * 
   * @return A string representing the body.
   */
  public String getMessage();
  
}
