/**
 * <copyright>
 *
 * Copyright (c) 2002-2003 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 *   IBM - Initial API and implementation
 *
 * </copyright>
 */
package org.eclipse.wsdl20.model;

/**
 * This interface represents the property element information item from the
 * WSDL 2.0 specification's abstract model (section 2.7). A property element
 * information item describes a set of possible values and is used to control
 * a feature's behaviour. A property consists of:
 * a required URI attribute information item
 * an optional required attribute information item
 * one required element information item of either constraint of value
 * 
 * The XML representation of a property is:
 * <property
 *   uri="xs:QName" 
 *   required="xs:boolean"? >
 *  <documentation />?
 *  [ <value /> | <constraint /> ]
 * </property>
 * 
 * @author Lawrence Mandel, IBM
 */
public interface Property extends ElementInfoItem
{
  /**
   * Returns whether this property is required.
   * 
   * @return True if this is required, false otherwise.
   */
  public boolean isReqiured();
  
  /**
   * Returns a simple type defintion constraining the value of the property.
   * 
   * @return A PropertyValue.
   */
  public PropertyValue getValue();
  
  /**
   * Returns a complex type definition constraining the value of the property.
   * 
   * @return A PropertyConstraint.
   */
  public PropertyConstraint getConstraint();
}
