/**
 * <copyright>
 *
 * Copyright (c) 2002-2003 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 *   IBM - Initial API and implementation
 *
 * </copyright>
 */
package org.eclipse.wsdl20.model;

/**
 * This interface represents the service element information item from the
 * WSDL 2.0 specification's abstract model (section 2.11). A service 
 * describes a set of endpoints at which the service is provided.
 * A service contains:
 * a required name attribute information item
 * a required interface element information item
 * one or more endpoint element information items
 * 
 * The XML representation of a service is:
 * <service
 *   name="xs:NCName" 
 *   interface="xs:QName" 
 *  <documentation />?
 *  <endpoint />+
 * </service>
 * 
 * @author Lawrence Mandel, IBM
 */
public interface Service extends ElementInfoItem
{
  /**
   * Returns the interface this service is exposing.
   * 
   * @return The Interface this service is exposing.
   */
  public Interface getInterface();
  
  /**
   * Returns a set of service endpoints.
   * 
   * @return An array of ServiceEndpoints.
   */
  public ServiceEndpoint[] getEndpoints();
}
