/**
 * <copyright>
 *
 * Copyright (c) 2002-2003 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 *   IBM - Initial API and implementation
 *
 * </copyright>
 */
package org.eclipse.wsdl20.model.factory;

import org.eclipse.wsdl20.model.exception.WSDLException;
import org.eclipse.wsdl20.model.xml.WSDLReader;

/**
 * A factory for creating WSDL objects.
 * 
 * @author Lawrence Mandel, IBM
 */
public abstract class WSDLFactory
{
  /**
   * There should be only one instance of this factory.
   */
  protected static WSDLFactory instance = null;

  /**
   * The default factory implementation.
   */
  private static String DEFAULT_FACTORY_IMPL = "org.eclipse.wsdl20.model.factory.impl.WSDLFactoryImpl";

  /**
   * Get the one and only instance of the factory.
   * 
   * @return The instance of the factory.
   * @throws WSDLException
   */
  public static WSDLFactory getInstance() throws WSDLException
  {
    if (instance == null)
    {
      try
      {
        Class factoryClass = WSDLFactory.class.getClassLoader().loadClass(DEFAULT_FACTORY_IMPL);
        instance = (WSDLFactory)factoryClass.newInstance();
      }
      catch (ClassNotFoundException e)
      {
        throw new WSDLException(e.getMessage());
      }
      catch (InstantiationException e)
      {
        throw new WSDLException(e.getMessage());
      }
      catch (IllegalAccessException e)
      {
        throw new WSDLException(e.getMessage());
      }
    }
    return instance;
  }

  /**
   * Return a new WSDL reader.
   * 
   * @return A new WSDL reader.
   */
  public abstract WSDLReader newWSDLReader();

}
