/**
 * <copyright>
 *
 * Copyright (c) 2002-2003 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 *   IBM - Initial API and implementation
 *
 * </copyright>
 */
package org.eclipse.wsdl20.model.impl;

import org.eclipse.wsdl20.model.BindingFaultReference;
import org.eclipse.wsdl20.model.MessageReference;

/**
 * An implementation of a binding fault reference from the WSDL 2.0 specification.
 * 
 * @author Lawrence Mandel, IBM
 */
public class BindingFaultReferenceImpl extends ElementInfoItemImpl implements BindingFaultReference
{
  private final String IN = "in";
  private final String OUT = "out";
  
  private MessageReference messageref = null;
  private String direction = null;
  
  /**
   * Set the message reference for that this binding fault reference relates to.
   * 
   * @param messageref The message reference to set.
   * @see #getMessageReference
   */
  public void setMessageReference(MessageReference messageref)
  {
    this.messageref = messageref;
  }
  
  /**
   * @see org.eclipse.wsdl20.model.BindingFaultReference#getMessageReference()
   * @see #setMessageReference
   */
  public MessageReference getMessageReference()
  {
    return messageref;
  }
  
  /**
   * @see org.eclipse.wsdl20.model.BindingFaultReference#getDirection()
   */
  public String getDirection()
  {
    if(direction == null)
     {
      if(getQName() == Constants.Q_ELEM_INFAULT)
       {
        this.direction = IN;
      }
      else if(getQName() == Constants.Q_ELEM_OUTFAULT)
       {
        this.direction = OUT;
      }
    }
    return direction;
  }
}
