/**
 * <copyright>
 *
 * Copyright (c) 2002-2003 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 *   IBM - Initial API and implementation
 *
 * </copyright>
 */
package org.eclipse.wsdl20.model.impl;

import java.util.List;
import java.util.Vector;

import javax.xml.namespace.QName;

import org.eclipse.wsdl20.model.Binding;
import org.eclipse.wsdl20.model.BindingOperation;
import org.eclipse.wsdl20.model.Feature;
import org.eclipse.wsdl20.model.Interface;
import org.eclipse.wsdl20.model.Property;

/**
 * An implementation of a binding from the WSDL 2.0 abstract model.
 * 
 * @author Lawrence Mandel, IBM
 */
public class BindingImpl extends ElementInfoItemImpl implements Binding
{
  protected Interface interf = null;
  protected List properties = new Vector();
  protected List features = new Vector();
  protected List operations = new Vector();
  
  /**
   * @see org.eclipse.wsdl20.model.Binding#getInterface()
   * @see #setInterface(Interface)
   */
  public Interface getInterface()
  {
    return interf;
  }
  
  /**
   * Set the interface for this binding.
   * 
   * @param interf The interface to set for this binding.
   * @see #getInterface()
   */
  public void setInterface(Interface interf)
  {
    this.interf = interf;
  }

  /**
   * @see org.eclipse.wsdl20.model.Binding#getBindingOperations()
   * @see #addBindingOperation(BindingOperation)
   */
  public BindingOperation[] getBindingOperations()
  {
    return (BindingOperation[])operations.toArray(new BindingOperation[operations.size()]);
  }

  /**
   * Add a binding operatin to the binding.
   * 
   * @param bindingoperation The binding operation to add.
   * @see #getBindingOperations()
   */
  public void addBindingOperation(BindingOperation bindingoperation)
  {
  	operations.add(bindingoperation);
  }
  
  /**
   * @see org.eclipse.wsdl20.model.Binding#getFeatures()
   * @see #addFeature(Feature)
   */
  public Feature[] getFeatures()
  {
    return (Feature[])features.toArray(new Feature[features.size()]);
  }

  /**
   * Add a feature to this binding.
   * 
   * @param feature The feature to add.
   * @see #getFeatures()
   */
  public void addFeature(Feature feature)
  {
  	features.add(feature);
  }
  /**
   * @see org.eclipse.wsdl20.model.Binding#getProperties()
   * @see #addProperty(Property)
   */
  public Property[] getProperties()
  {
    return (Property[])properties.toArray(new Property[properties.size()]);
  }
  
  /**
   * Add a property to this binding.
   * 
   * @param property The property to add.
   * @see #getProperties()
   */
  public void addProperty(Property property)
  {
  	properties.add(property);
  }

  /**
   * @see org.eclipse.wsdl20.model.ElementInfoItem#getQName()
   */
  public QName getQName()
  {
    return Constants.Q_ELEM_BINDING;
  }

}
