/**
 * <copyright>
 *
 * Copyright (c) 2002-2003 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 *   IBM - Initial API and implementation
 *
 * </copyright>
 */
package org.eclipse.wsdl20.model.impl;

import org.eclipse.wsdl20.model.BindingMessageReference;
import org.eclipse.wsdl20.model.MessageReference;

/**
 * An implementation of a binding message reference from the WSDL 2.0 specification.
 * 
 * @author Lawrence Mandel, IBM
 */
public class BindingMessageReferenceImpl extends ElementInfoItemImpl implements BindingMessageReference
{
  private final String IN = "in";
  private final String OUT = "out";
  
  private MessageReference messageref = null;
  private String direction = null;

  /**
   * Set the message reference within the operation which this binding message reference
   * is specifying the details for.
   * 
   * @param messageref The message reference to set.
   * @see #getMessage
   */
  public void setMessage(MessageReference messageref)
  {
    this.messageref = messageref;
  }

  /**
   * @see org.eclipse.wsdl20.model.BindingMessageReference#getMessage()
   * @see #setMessage
   */
  public MessageReference getMessage()
  {
    return messageref;
  }
  
  /**
   * @see org.eclipse.wsdl20.model.BindingMessageReference#getDirection()
   */
  public String getDirection()
  {
    if (direction == null)
     {
      if (getQName() == Constants.Q_ELEM_INPUT)
       {
        this.direction = IN;
      }
      else if (getQName() == Constants.Q_ELEM_OUTPUT)
       {
        this.direction = OUT;
      }
    }
    return direction;
  }

}
