/**
 * <copyright>
 *
 * Copyright (c) 2002-2003 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 *   IBM - Initial API and implementation
 *
 * </copyright>
 */
package org.eclipse.wsdl20.model.impl;

import java.util.List;
import java.util.Vector;

import javax.xml.namespace.QName;

import org.eclipse.wsdl20.model.BindingFaultReference;
import org.eclipse.wsdl20.model.BindingMessageReference;
import org.eclipse.wsdl20.model.BindingOperation;
import org.eclipse.wsdl20.model.Feature;
import org.eclipse.wsdl20.model.Property;

/**
 * An implementation of a binding opearation from the WSDL 2.0 specification.
 * 
 * @author Lawrence Mandel, IBM
 */
public class BindingOperationImpl extends ElementInfoItemImpl implements BindingOperation
{
  private List messageReferences = new Vector();
  private List faultReferences = new Vector();
  private List features = new Vector();
  private List properties = new Vector();
  
  /**
   * Add a message reference to this binding operation.
   * 
   * @param messageref The message reference to add to this binding operation.
   * @see #getBindingMessageReferences
   */
  public void addBindingMessageReference(BindingMessageReference messageref)
  {
    messageReferences.add(messageref);
  }
  
  /**
   * @see org.eclipse.wsdl20.model.BindingOperation#getMessageReferences()
   * @see #addBindingMessageReference
   */
  public BindingMessageReference[] getBindingMessageReferences()
  {
    return (BindingMessageReference[]) messageReferences.toArray(new BindingMessageReference[messageReferences.size()]);
  }

  /**
   * Add a fault reference to this binding operation.
   * 
   * @param faultref The fault reference to add to this binding operation.
   * @see #getBindingFaultReferences
   */
  public void addBindingFaultReference(BindingFaultReference faultref)
  {
    faultReferences.add(faultref);
  }
  
  /**
   * @see org.eclipse.wsdl20.model.BindingOperation#getFaultReferences()
   * @see #addBindingFaultReference
   */
  public BindingFaultReference[] getBindingFaultReferences()
  {
    return (BindingFaultReference[]) faultReferences.toArray(new BindingFaultReference[faultReferences.size()]);
  }

  /**
   * Add a feature to the binding operation.
   * 
   * @param feature The feature to add to the binding operation.
   * @see #getFeatures
   */
  public void addFeature(Feature feature)
  {
    features.add(feature);
  }
  
  /**
   * @see org.eclipse.wsdl20.model.BindingOperation#getFeatures()
   * @see #addFeature
   */
  public Feature[] getFeatures()
  {
    return (Feature[]) features.toArray(new Feature[features.size()]);
  }

  /**
   * Add a property to the binding operation.
   * 
   * @param property The property to add to the binding operation.
   * @see #getProperties
   */
  public void addProperty(Property property)
  {
    properties.add(property);
  }
  /**
   * @see org.eclipse.wsdl20.model.BindingOperation#getProperties()
   * @see #addProperty
   */
  public Property[] getProperties()
  {
    return (Property[])properties.toArray(new Property[properties.size()]);
  }

  /**
   * @see org.eclipse.wsdl20.model.ElementInfoItem#getQName()
   */
  public QName getQName()
  {
    return Constants.Q_ELEM_OPERATION;
  }

}
