/**
 * <copyright>
 *
 * Copyright (c) 2002-2003 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 *   IBM - Initial API and implementation
 *
 * </copyright>
 */
package org.eclipse.wsdl20.model.impl;

import java.util.Arrays;
import java.util.List;

import javax.xml.namespace.QName;

/**
 * Constants for WSDL 2.0.
 * 
 * @author Lawrence Mandel, IBM
 */
public class Constants
{
  // Resource Bundle name
  public static final String RB_BASE_NAME = "wsdl20model";
  // Namespace URIs.
  public static final String NS_URI_WSDL = "http://www.w3.org/@@@@/@@/wsdl";
  public static final String NS_URI_XMLNS = "http://www.w3.org/2000/xmlns/";
  public static final String NS_URI_EMPTY = "";

  // Top-level element names.
  public static final String ELEM_DEFINITIONS = "definitions";
  public static final String ELEM_IMPORT = "import";
  public static final String ELEM_INCLUDE = "include";
  public static final String ELEM_TYPES = "types";
  public static final String ELEM_INTERFACE = "interface";
  public static final String ELEM_BINDING = "binding";
  public static final String ELEM_SERVICE = "service";

  // Non top-level element names.
  public static final String ELEM_PART = "part";
  public static final String ELEM_OPERATION = "operation";
  public static final String ELEM_FEATURE = "feature";
  public static final String ELEM_PROPERTY = "property";
  public static final String ELEM_VALUE = "value";
  public static final String ELEM_CONSTRAINT = "constraint";
  public static final String ELEM_INPUT = "input";
  public static final String ELEM_OUTPUT = "output";
  public static final String ELEM_INFAULT = "infault";
  public static final String ELEM_OUTFAULT = "outfault";
  public static final String ELEM_ENDPOINT = "endpoint";
  public static final String ELEM_DOCUMENTATION = "documentation";

  // Top-level qualified element names.
  public static final QName Q_ELEM_DEFINITIONS = new QName(NS_URI_WSDL, ELEM_DEFINITIONS);
  public static final QName Q_ELEM_IMPORT = new QName(NS_URI_WSDL, ELEM_IMPORT);
  public static final QName Q_ELEM_INCLUDE = new QName(NS_URI_WSDL, ELEM_INCLUDE);
  public static final QName Q_ELEM_TYPES = new QName(NS_URI_WSDL, ELEM_TYPES);
  public static final QName Q_ELEM_INTERFACE = new QName(NS_URI_WSDL, ELEM_INTERFACE);
  public static final QName Q_ELEM_BINDING = new QName(NS_URI_WSDL, ELEM_BINDING);
  public static final QName Q_ELEM_SERVICE = new QName(NS_URI_WSDL, ELEM_SERVICE);

  // Non top-level qualified element names.
  public static final QName Q_ELEM_OPERATION = new QName(NS_URI_WSDL, ELEM_OPERATION);
  public static final QName Q_ELEM_INPUT = new QName(NS_URI_WSDL, ELEM_INPUT);
  public static final QName Q_ELEM_OUTPUT = new QName(NS_URI_WSDL, ELEM_OUTPUT);
  public static final QName Q_ELEM_INFAULT = new QName(NS_URI_WSDL, ELEM_INFAULT);
  public static final QName Q_ELEM_OUTFAULT = new QName(NS_URI_WSDL, ELEM_OUTFAULT);
  public static final QName Q_ELEM_FEATURE = new QName(NS_URI_WSDL, ELEM_FEATURE);
  public static final QName Q_ELEM_PROPERTY = new QName(NS_URI_WSDL, ELEM_PROPERTY);
  public static final QName Q_ELEM_VALUE = new QName(NS_URI_WSDL, ELEM_VALUE);
  public static final QName Q_ELEM_CONSTRAINT = new QName(NS_URI_WSDL, ELEM_CONSTRAINT);
  public static final QName Q_ELEM_ENDPOINT = new QName(NS_URI_WSDL, ELEM_ENDPOINT);
  public static final QName Q_ELEM_DOCUMENTATION = new QName(NS_URI_WSDL, ELEM_DOCUMENTATION);

  // Attribute names.
  public static final String ATTR_NAME = "name";
  public static final String ATTR_TARGET_NAMESPACE = "targetNamespace";
  public static final String ATTR_ELEMENT = "element";
  public static final String ATTR_TYPE = "type";
  public static final String ATTR_MESSAGE = "message";
  public static final String ATTR_BINDING = "binding";
  public static final String ATTR_XMLNS = "xmlns";
  public static final String ATTR_NAMESPACE = "namespace";
  public static final String ATTR_LOCATION = "location";
  public static final String ATTR_REQUIRED = "required";
  public static final String ATTR_URI = "uri";
  public static final String ATTR_STYLE_DEFAULT = "styleDefault";
  public static final String ATTR_PATTERN = "pattern";
  public static final String ATTR_STYLE = "style";
  public static final String ATTR_MESSAGE_REFERENCE = "messageReference";

  // Qualified attribute names.
  public static final QName Q_ATTR_REQUIRED = new QName(NS_URI_WSDL, ATTR_REQUIRED);

  // XML Declaration string.
  public static final String XML_DECL_DEFAULT = "UTF-8";
  public static final String XML_DECL_START = "<?xml version=\"1.0\" encoding=\"";
  public static final String XML_DECL_END = "\"?>";

  // Feature names.
  //public static final String FEATURE_VERBOSE = "javax.wsdl.verbose";
  //public static final String FEATURE_IMPORT_DOCUMENTS = "javax.wsdl.importDocuments";

  // For handling XSD documents (temporary).
  public static final String NS_URI_XSD_1999 = "http://www.w3.org/1999/XMLSchema";
  public static final String NS_URI_XSD_2000 = "http://www.w3.org/2000/10/XMLSchema";
  public static final String NS_URI_XSD_2001 = "http://www.w3.org/2001/XMLSchema";
  public static final String SCHEMA = "schema";
  public static final QName Q_ELEM_XSD_1999 = new QName(NS_URI_XSD_1999, SCHEMA);
  public static final QName Q_ELEM_XSD_2000 = new QName(NS_URI_XSD_2000, SCHEMA);
  public static final QName Q_ELEM_XSD_2001 = new QName(NS_URI_XSD_2001, SCHEMA);
  public static final List XSD_QNAME_LIST =
    Arrays.asList(new QName[] { Q_ELEM_XSD_1999, Q_ELEM_XSD_2000, Q_ELEM_XSD_2001 });

}
