/**
 * <copyright>
 *
 * Copyright (c) 2002-2003 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 *   IBM - Initial API and implementation
 *
 * </copyright>
 */
package org.eclipse.wsdl20.model.impl;

import java.util.List;
import java.util.Vector;

import javax.xml.namespace.QName;

import org.eclipse.wsdl20.model.Binding;
import org.eclipse.wsdl20.model.Definitions;
import org.eclipse.wsdl20.model.Import;
import org.eclipse.wsdl20.model.Include;
import org.eclipse.wsdl20.model.Interface;
import org.eclipse.wsdl20.model.Service;
import org.eclipse.wsdl20.model.Types;

/**
 * An implementation of a definitions element from the WSDL 2.0 specification.
 * 
 * @author Lawrence Mandel, IBM
 */
public class DefinitionsImpl extends ElementInfoItemImpl implements Definitions
{
  private List imports = new Vector();
  private List includes = new Vector();
  private List interfaces = new Vector();
  private List bindings = new Vector();
  private List services = new Vector();
  private Types types = null;
  
  /**
   * Add an import element to the definitions element.
   * 
   * @param importelement The import element to add to the definitions element.
   * @see #getImports
   */
  public void addImport(Import importelement)
  {
    imports.add(importelement);
  }
  
  /**
   * @see org.eclipse.wsdl20.model.Definitions#getImports()
   * @see #addImport
   */
  public Import[] getImports()
  {
    return (Import[])imports.toArray(new Import[imports.size()]);
  }
  
  /**
   * Add an include element to the definitions element.
   * 
   * @param include The include element to add to the definitions element.
   * @see #getIncludes
   */
  public void addInclude(Include include)
  {
    includes.add(include);
  }

  /**
   * @see org.eclipse.wsdl20.model.Definitions#getIncludes()
   * @see #addInclude
   */
  public Include[] getIncludes()
  {
    return (Include[])includes.toArray(new Include[includes.size()]);
  }

  /**
   * Add an interface element to the definitions element.
   * 
   * @param interfaceelement The interface element to add to the definitions element.
   * @see #getInterfaces
   */
  public void addInterface(Interface interfaceelement)
  {
    interfaces.add(interfaceelement);
  }
  
  /**
   * @see org.eclipse.wsdl20.model.Definitions#getInterfaces()
   * @see #addInterface
   */
  public Interface[] getInterfaces()
  {
    return (Interface[])interfaces.toArray(new Interface[interfaces.size()]);
  }

  /**
   * Add a binding element to the definitions element.
   * 
   * @param binding The binding to add.
   * @see #getBindings
   */
  public void addBinding(Binding binding)
  {
    bindings.add(binding);
  }
  /**
   * @see org.eclipse.wsdl20.model.Definitions#getBindings()
   * @see #addBinding
   */
  public Binding[] getBindings()
  {
    return (Binding[])bindings.toArray(new Binding[bindings.size()]);
  }
  
  /**
   * Add a service element to the definitions element.
   * 
   * @param service The service to add.
   * @see #getServices
   */
  public void addService(Service service)
  {
    services.add(service);
  }

  /**
   * @see org.eclipse.wsdl20.model.Definitions#getServices()
   * @see #addService
   */
  public Service[] getServices()
  {
    return (Service[])services.toArray(new Service[services.size()]);
  }
  
  /**
   * Add a types element to the definitions element.
   * 
   * @param types The types element to add.
   * @see #getTypes
   */
  public void setTypes(Types types)
  {
    this.types = types;
  }

  /**
   * @see org.eclipse.wsdl20.model.Definitions#getTypes()
   * @see #setTypes
   */
  public Types getTypes()
  {
    return types;
  }

  /**
   * @see org.eclipse.wsdl20.model.ElementInfoItem#getQName()
   */
  public QName getQName()
  {
    return Constants.Q_ELEM_DEFINITIONS;
  }

}
