/**
 * <copyright>
 *
 * Copyright (c) 2002-2003 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 *   IBM - Initial API and implementation
 *
 * </copyright>
 */
package org.eclipse.wsdl20.model.impl;

import org.eclipse.wsdl20.model.FaultReference;
import org.eclipse.wsdl20.model.MessageReference;

/**
 * An implementation of a fault reference from the WSDL 2.0 specification.
 * 
 * @author Lawrence Mandel, IBM
 */
public class FaultReferenceImpl extends ElementInfoItemImpl implements FaultReference
{
  private final String IN = "in";
  private final String OUT = "out";
  
  private String direction = null;
  private MessageReference messagereference = null;
  private String message = null;

  /**
   * @see org.eclipse.wsdl20.model.FaultReference#getDirection()
   */
  public String getDirection()
  {
    if(direction == null)
    {
      if(qname == Constants.Q_ELEM_INFAULT)
      {
        direction = IN;
      }
      else if(qname == Constants.Q_ELEM_OUTFAULT)
      {
        direction = OUT;
      }
    }
    return direction;
  }

  /**
   * Set the message reference of this fault reference.
   * 
   * @param messageref The message reference to set.
   * @see #getMessageReference
   */
  public void setMessageReference(MessageReference messageref)
  {
    this.messagereference = messageref;
  }
  
  /**
   * @see org.eclipse.wsdl20.model.FaultReference#getMessageReference()
   * @see #setMessageReference
   */
  public MessageReference getMessageReference()
  {
    return messagereference;
  }
  
  /**
   * @see org.eclipse.wsdl20.model.FaultReference#getMessage()
   */
  public String getMessage()
  {
    if(message == null)
    {
      message = getAttributeInfoItemValue(Constants.NS_URI_EMPTY, Constants.ATTR_MESSAGE);
    }
    return message;
  }

}
