/**
 * <copyright>
 *
 * Copyright (c) 2002-2003 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 *   IBM - Initial API and implementation
 *
 * </copyright>
 */
package org.eclipse.wsdl20.model.impl;

import java.util.List;
import java.util.Vector;

import javax.xml.namespace.QName;

import org.eclipse.wsdl20.model.Feature;
import org.eclipse.wsdl20.model.Interface;
import org.eclipse.wsdl20.model.InterfaceOperation;
import org.eclipse.wsdl20.model.Property;

/**
 * An implementation of an interface from the WSDL 2.0 specification.
 * 
 * @author Lawrence Mandel, IBM
 */
public class InterfaceImpl extends ElementInfoItemImpl implements Interface
{ 
  private String styledefault = null;
  private List operations = new Vector();
  private List features = new Vector();
  private List properties = new Vector();

  /**
   * @see org.eclipse.wsdl20.model.Interface#getExtendedInterfaces()
   */
  public Interface[] getExtendedInterfaces()
  {
    // TODO return the extended interfaces
    return null;
  }

  /**
   * @see org.eclipse.wsdl20.model.Interface#getStyleDefault()
   */
  public String getStyleDefault()
  {
    if(styledefault == null)
    {  
      styledefault = getAttributeInfoItemValue(Constants.NS_URI_EMPTY, Constants.ATTR_STYLE_DEFAULT);
    }
    return styledefault;
  }

  /**
   * @see org.eclipse.wsdl20.model.Interface#getOperations()
   * @see #addOperation(InterfaceOperation)
   */
  public InterfaceOperation[] getOperations()
  {
    return (InterfaceOperation[])operations.toArray(new InterfaceOperation[operations.size()]);
  }
  
  /**
   * Add an interface operation to this interface.
   * 
   * @param operation The operation to add to this interface.
   * @see #getOperations()
   */
  public void addOperation(InterfaceOperation operation)
  {
    operations.add(operation);
  }

  /**
   * @see org.eclipse.wsdl20.model.Interface#getFeatures()
   * @see #addFeature(Feature)
   */
  public Feature[] getFeatures()
  {
    return (Feature[])features.toArray(new Feature[features.size()]);
  }
  
  /**
   * Add a feature to this interface.
   * 
   * @param feature The feature to add to this interface.
   * @see #getFeatures()
   */
  public void addFeature(Feature feature)
  {
    features.add(feature);
  }

  /**
   * @see org.eclipse.wsdl20.model.Interface#getProperties()
   * @see #addFeature(Feature)
   */
  public Property[] getProperties()
  {
    return (Property[])properties.toArray(new Property[properties.size()]);
  }
  
  /**
   * Add a property to this interface.
   * 
   * @param property The property to add to this interface.
   * @see #getProperties()
   */
  public void addProperty(Property property)
  {
    properties.add(property);
  }

  /**
   * @see org.eclipse.wsdl20.model.ElementInfoItem#getQName()
   */
  public QName getQName()
  {
    return Constants.Q_ELEM_INTERFACE;
  }

}
