/**
 * <copyright>
 *
 * Copyright (c) 2002-2003 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 *   IBM - Initial API and implementation
 *
 * </copyright>
 */
package org.eclipse.wsdl20.model.impl;

import java.util.List;
import java.util.Vector;

import javax.xml.namespace.QName;

import org.eclipse.wsdl20.model.FaultReference;
import org.eclipse.wsdl20.model.Feature;
import org.eclipse.wsdl20.model.InterfaceOperation;
import org.eclipse.wsdl20.model.MessageReference;
import org.eclipse.wsdl20.model.Property;

/**
 * A representation of an interface operation from the WSDL 2.0 abstract model.
 * 
 * @author Lawrence Mandel, IBM
 */
public class InterfaceOperationImpl extends ElementInfoItemImpl implements InterfaceOperation
{
  private List messageReferences = new Vector();
  private List faultReferences = new Vector();
  private List features = new Vector();
  private List properties = new Vector();

  /**
   * @see org.eclipse.wsdl20.model.InterfaceOperation#getMessageReferences()
   * @see #addMessageReference(MessageReference)
   */
  public MessageReference[] getMessageReferences()
  {
    return (MessageReference[])messageReferences.toArray(new MessageReference[messageReferences.size()]);
  }
  
  /**
   * Add a message reference to this interface operation.
   * 
   * @param messageref The message reference to add.
   * @see #getMessageReferences()
   */
  public void addMessageReference(MessageReference messageref)
  {
    messageReferences.add(messageref);
  }

  /**
   * @see org.eclipse.wsdl20.model.InterfaceOperation#getFaultReferences()
   * @see #addFaultReference(FaultReference)
   */
  public FaultReference[] getFaultReferences()
  {
    return (FaultReference[])faultReferences.toArray(new FaultReference[faultReferences.size()]);
  }

  /**
   * Add a fault reference to this interface operation.
   * 
   * @param faultref The fault reference to add.
   * @see #getFaultReferences()
   */
  public void addFaultReference(FaultReference faultref)
  {
    faultReferences.add(faultref);
  }
  
  /**
   * @see org.eclipse.wsdl20.model.InterfaceOperation#getMessageExchangePattern()
   */
  public String getMessageExchangePattern()
  {
    return getAttributeInfoItemValue(Constants.NS_URI_EMPTY, Constants.ATTR_PATTERN);
  }

  /**
   * @see org.eclipse.wsdl20.model.InterfaceOperation#getStyle()
   */
  public String getStyle()
  {
    return getAttributeInfoItemValue(Constants.NS_URI_EMPTY, Constants.ATTR_STYLE);
  }

  /**
   * @see org.eclipse.wsdl20.model.InterfaceOperation#getFeatures()
   * @see #addFeature(Feature)
   */
  public Feature[] getFeatures()
  {
    return (Feature[])features.toArray(new Feature[features.size()]);
  }
  
  /**
   * Add a feature to this interface operation.
   * 
   * @param feature The feature to add.
   * @see #getFeatures()
   */
  public void addFeature(Feature feature)
  {
    features.add(feature);
  }

  /**
   * @see org.eclipse.wsdl20.model.InterfaceOperation#getProperties()
   * @see #addProperty(Property)
   */
  public Property[] getProperties()
  {
    return (Property[])properties.toArray(new Property[properties.size()]);
  }
  
  /**
   * Add a property to this interface operation.
   * 
   * @param property The property to add.
   * @see #getProperties()
   */
  public void addProperty(Property property)
  {
    properties.add(property);
  }
  
  /**
   * @see org.eclipse.wsdl20.model.ElementInfoItem#getQName()
   */
  public QName getQName()
  {
    return Constants.Q_ELEM_OPERATION;
  }

}
