/**
 * <copyright>
 *
 * Copyright (c) 2002-2003 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 *   IBM - Initial API and implementation
 *
 * </copyright>
 */
package org.eclipse.wsdl20.model.impl;

import org.eclipse.wsdl20.model.Property;
import org.eclipse.wsdl20.model.PropertyConstraint;
import org.eclipse.wsdl20.model.PropertyValue;

/**
 * An implementation of a property from the WSDL 2.0 specification.
 * 
 * @author Lawrence Mandel, IBM
 */
public class PropertyImpl extends ElementInfoItemImpl implements Property
{
  private final String TRUE = "true";
  
  private PropertyValue value = null;
  private PropertyConstraint constraint = null;
  
  /**
   * @see org.eclipse.wsdl20.model.Property#isReqiured()
   */
  public boolean isReqiured()
  {
    String required = getAttributeInfoItemValue(Constants.NS_URI_EMPTY, Constants.ATTR_REQUIRED);
    if(required.equals(TRUE) || required.equals("1"))
    {
      return true;
    }
    return false;
  }

  /**
   * @see org.eclipse.wsdl20.model.Property#getValue()
   * @see #setValue(PropertyValue)
   */
  public PropertyValue getValue()
  {
    return value;
  }
  
  /**
   * Set the value for this property.
   * 
   * @param value The value to set for this property.
   * @see #getValue()
   */
  public void setValue(PropertyValue value)
  {
    this.value = value;
  }

  /**
   * @see org.eclipse.wsdl20.model.Property#getConstraint()
   * @see #setConstraint(PropertyConstraint)
   */
  public PropertyConstraint getConstraint()
  {
    return constraint;
  }
  
  /**
   * Set the constraint for this property.
   * 
   * @param constraint The constaint to set for this property.
   * @see #getConstraint()
   */
  public void setConstraint(PropertyConstraint constraint)
  {
    this.constraint = constraint;
  }

}
