/**
 * <copyright>
 *
 * Copyright (c) 2002-2003 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 *   IBM - Initial API and implementation
 *
 * </copyright>
 */
package org.eclipse.wsdl20.model.impl;

import java.util.List;
import java.util.Vector;

import javax.xml.namespace.QName;

import org.eclipse.wsdl20.model.Interface;
import org.eclipse.wsdl20.model.Service;
import org.eclipse.wsdl20.model.ServiceEndpoint;

/**
 * An implementation of a service from the WSDL 2.0 model.
 * 
 * @author Lawrence Mandel, IBM
 */
public class ServiceImpl extends ElementInfoItemImpl implements Service
{
  protected Interface interf = null;
  protected List endpoints = new Vector();
  
  /**
   * @see org.eclipse.wsdl20.model.Service#getInterface()
   * @see #setInterface(Interface)
   */
  public Interface getInterface()
  {
    return interf;
  }
  
  /**
   * Set the interface for this service.
   * 
   * @param interf The interface to set for this service.
   * @see #getInterface()
   */
  public void setInterface(Interface interf)
  {
    this.interf = interf;
  }

  /**
   * @see org.eclipse.wsdl20.model.Service#getEndpoints()
   * @see #addEndpoint(ServiceEndpoint)
   */
  public ServiceEndpoint[] getEndpoints()
  {
    return (ServiceEndpoint[])endpoints.toArray(new ServiceEndpoint[endpoints.size()]);
  }
  
  /**
   * Add an endpoint to this service.
   * 
   * @param endpoint The endpoint to add.
   * @see #getEndpoints()
   */
  public void addEndpoint(ServiceEndpoint endpoint)
  {
    endpoints.add(endpoint);
  }

  /**
   * @see org.eclipse.wsdl20.model.ElementInfoItem#getQName()
   */
  public QName getQName()
  {
    return Constants.Q_ELEM_SERVICE;
  }

}
