/**
 * <copyright>
 *
 * Copyright (c) 2002-2003 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 *   IBM - Initial API and implementation
 *
 * </copyright>
 */
package org.eclipse.wsdl20.model.xml;

/**
 * A representation of an error produced by the reader. Allows retrieval of all the
 * relevant error information.
 * 
 * @author Lawrence Mandel, IBM
 */
public interface ReaderError
{
  
  /**
   * Return the message associated with this error.
   * 
   * @return The message associated with this error.
   */
  public String getMessage();
  
  /**
   * Return the line where this error is located.
   * 
   * @return The line where this error is located.
   */
  public int getLine();
  
  /**
   * Return the column where this error is located.
   * 
   * @return The column where this error is located.
   */
  public int getColumn();
  
  /**
   * Returns the URI of the file that contains this error.
   * 
   * @return The URI of the file that contains this error.
   */
  public String getFileURI();

}
