/**
 * <copyright>
 *
 * Copyright (c) 2002-2003 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 *   IBM - Initial API and implementation
 *
 * </copyright>
 */
package org.eclipse.wsdl20.model.xml;

import java.util.List;

import org.eclipse.wsdl20.model.Definitions;
import org.eclipse.wsdl20.model.exception.WSDLException;
import org.w3c.dom.Document;

/**
 * A WSDL reader will create a WSDL 2.0 model from a document or a URI.
 * 
 * @author Lawrence Mandel, IBM
 */
public interface WSDLReader
{
  /**
   * Read a WSDL document and create a WSDL model from a URI. Return the definitions element from
   * the WSDL model
   * 
   * @param uri The uri of the WSDL document to read.
   * @return The definitions element from the WSDL model.
   * @throws WSDLException
   */
  public Definitions readWSDL(String uri) throws WSDLException;
  
  /**
   * Read a WSDL document and create a WSDL model from an existing document element. Return the 
   * definitions element from the WSDL model.
   * 
   * @param uri The uri the document represents.
   * @param document The existing document to create the WSDL model from.
   * @return The definitons element from the WSDL model.
   * @throws WSDLException
   */
  public Definitions readWSDL(String uri, Document document) throws WSDLException;
  
  /**
   * Return a list of error messages generated from the reader.
   * 
   * @return A list of error messages generated from the reader.
   */
  public List getReaderErrors();

}
