/**
 * <copyright>
 *
 * Copyright (c) 2002-2003 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 *   IBM - Initial API and implementation
 *
 * </copyright>
 */
package org.eclipse.wsdl20.model.xml.impl;

import org.eclipse.wsdl20.model.xml.ReaderError;

/**
 * An implementation of a reader error.
 * 
 * @author Lawrence Mandel, IBM
 */
public class ReaderErrorImpl implements ReaderError
{
  private String message = null;
  private int line = 0;
  private int column = 0;
  private String uri = null;
  
  /**
   * Constructor.
   * 
   * @param message The error message.
   * @param line The line location of the error message.
   * @param column The column location of the error message.
   * @param uri The uri of the file that contains the error message.
   */
  public ReaderErrorImpl(String message, int line, int column, String uri)
  {
    this.message = message;
    this.line = line;
    this.column = column;
    this.uri = uri;
  }
  /**
   * @see org.eclipse.wsdl20.model.xml.ReaderError#getMessage()
   */
  public String getMessage()
  {
    return message;
  }

  /**
   * @see org.eclipse.wsdl20.model.xml.ReaderError#getLine()
   */
  public int getLine()
  {
    return line;
  }

  /**
   * @see org.eclipse.wsdl20.model.xml.ReaderError#getColumn()
   */
  public int getColumn()
  {
    return column;
  }

  /**
   * @see org.eclipse.wsdl20.model.xml.ReaderError#getFileURI()
   */
  public String getFileURI()
  {
    return uri;
  }

}
