/**
 * <copyright>
 *
 * Copyright (c) 2002-2003 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 *   IBM - Initial API and implementation
 *
 * </copyright>
 */
package org.eclipse.wsdl20.model.xml.impl;

import java.util.ResourceBundle;
import java.text.MessageFormat;

/**
 * A convenience class for working with resources in a resource bundle.
 * 
 * @author Lawrence Mandel, IBM
 */
public class ResourceBundleHelper
{
  protected ResourceBundle resourcebundle;

  /**
   * Constructor.
   * 
   * @param rb The resource bundle to work with.
   */
  public ResourceBundleHelper(ResourceBundle rb)
  {
    resourcebundle = rb;
  }

  /**
  * Gets the string resource for the given key.
  * 
  * @param key The key for the resource.
  * @return The string from the resource bundle.
  */
  public String getString(String key)
  {
    return resourcebundle.getString(key);
  }

  /**
   * Gets the string resource for the given key and does one substitution.
   * 
   * @param key The key for the resource.
   * @param s1 The substitution to perform.
   * @return The string from the resource bundle.
   */
  public String getString(String key, Object s1)
  {
    return MessageFormat.format(getString(key), new Object[] { s1 });
  }

  /**
   * Gets the string resource for the given key and does two substitutions.
   * 
   * @param key The key for the resource.
   * @param s1 The first substitution to perform.
   * @param s2 The second substitution to perform.
   * @return The string from the resource bundle.
   */
  public String getString(String key, Object s1, Object s2)
  {
    return MessageFormat.format(getString(key), new Object[] { s1, s2 });
  }

  /**
   *  Gets the string resource for the given key and does three substitutions.
   * 
   * @param key The key for the resource.
   * @param s1 The first substitution to perform.
   * @param s2 The second substitution to perform.
   * @param s3 The third substitution to perform.
   * @return The string from the resource bundle.
   */
  public String getString(String key, Object s1, Object s2, Object s3)
  {
    return MessageFormat.format(getString(key), new Object[] { s1, s2, s3 });
  }
}
