/**
 * <copyright>
 *
 * Copyright (c) 2002-2003 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 *   IBM - Initial API and implementation
 *
 * </copyright>
 */
package org.eclipse.wsdl.validate;

import java.util.HashMap;

/**
 * An interface for a WSDL validation report.
 * 
 * @author Lawrence Mandel, IBM
 */
public interface ValidationReport
{
  /**
   * Returns the URI for the file the report refers to.
   * 
   * @return The URI for the file the report refers to.
   */
  public String getFileURI();
  
  /**
   * Returns whether the file is valid according to the WSDL specification.
   * 
   * @return True if the file is WSDL valid, false otherwise.
   */
  public boolean isWSDLValid();

  /**
   * Returns an array of validation messages.
   * 
   * @return An array of validation messages.
   */
  public ValidationMessage[] getValidationMessages();
  
  /**
   * Returns true if there are errors, false otherwise.
   * 
   * @return True if there are errors, false otherwise.
   */
  public boolean hasErrors();
  
  public HashMap getNestedMessages();

}
