/**
 * <copyright>
 *
 * Copyright (c) 2002-2003 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 *   IBM - Initial API and implementation
 *
 * </copyright>
 */
package org.eclipse.wsdl.validate.internal.resolver;

import org.eclipse.wsdl.validate.resolver.IURIResolver;

/**
 * A delegate to hold information about an extension URI resolver.
 * 
 * @author Lawrence Mandel, IBM
 */
public class URIResolverDelegate
{
  private String classname;
  private ClassLoader classloader;
  private IURIResolver resolver = null;
  
  
  /**
   * Constructor.
   * 
   * @param classname The class name of the URI resolver.
   * @param classloader The class loader to use to load the URI resolver.
   */
  public URIResolverDelegate(String classname, ClassLoader classloader)
  {
    this.classname = classname;
    this.classloader = classloader;
  }
  
  /**
   * Get the URI resolver described by this delegate.
   * 
   * @return The URI resolver described by this delegate.
   */
  public IURIResolver getURIResolver()
  {
    if(resolver == null)
    {
      try
      {
        resolver = (IURIResolver)classloader.loadClass(classname).newInstance();
      }
      catch(Exception e)
      {
        try
        {
          resolver = (IURIResolver)getClass().getClassLoader().loadClass(classname).newInstance();
        }
        catch(Exception e2)
        {
        }
      }
    }
    return resolver;
  }
}
