/**
 * <copyright>
 *
 * Copyright (c) 2002-2003 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 *   IBM - Initial API and implementation
 *
 * </copyright>
 */
package org.eclipse.wsdl.validate.internal.xml;

/**
 * Factory for generating objects needed for XML Conformance validation.
 * 
 * @author Lawrence Mandel, IBM
 */
public abstract class AbstractXMLConformanceFactory
{
  protected static AbstractXMLConformanceFactory instance;
  
  /**
   * Returns the instance of this factory.
   * 
   * @return the instance of this factory
   */
  public static AbstractXMLConformanceFactory getInstance()
  {
    if (instance == null)
    {
      instance = new DefaultXMLConformanceFactory();
    }
    return instance;
  }
  
  /**
   * Set the implementation for this factory to use.
   * 
   * @param factory - the implementation this factory will use
   */
  public static void setImplementation(AbstractXMLConformanceFactory factory)
  {
    instance = factory;
  }
  
  /**
   * Return an XML validator.
   * 
   * @return an XML validator
   */
  abstract public IXMLValidator getXMLValidator();
}
