/**
 * <copyright>
 *
 * Copyright (c) 2002-2003 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 *   IBM - Initial API and implementation
 *
 * </copyright>
 */
package org.eclipse.wsdl.validate.wsdl11.internal;

/**
 * Holds the location information for an element in a document.
 * 
 * @author Lawrence Mandel, IBM
 */
public class LocationHolder
{
  private int line;
  private int column;
  private String uri;
  
  /**
   * Constructor.
   * 
   * @param line The line number.
   * @param column The column number.
   * @param uri The URI of the document.
   */
  public LocationHolder(int line, int column, String uri)
  {
    this.line = line;
    this.column = column;
    this.uri = uri;
  }
  
  /**
   * Get the line number.
   * 
   * @return The line number.
   */
  public int getLine()
  {
    return line;
  }
  
  /**
   * Get the column number.
   * 
   * @return The column number.
   */
  public int getColumn()
  {
    return column;
  }
  
  /**
   * Get the file URI.
   * 
   * @return The file URI.
   */
  public String getURI()
  {
    return uri;
  }
}
