/**
 * <copyright>
 *
 * Copyright (c) 2002-2003 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 *   IBM - Initial API and implementation
 *
 * </copyright>
 */
package org.eclipse.wsdl.validate.ui.ant;

import java.io.IOException;

import org.apache.tools.ant.types.DTDLocation;
import org.apache.tools.ant.types.XMLCatalog;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;

/**
 * An implementation of the WSDL Validator's XML Catalog that uses the XML Catalog
 * from ant.
 * 
 * @author Lawrence Mandel, IBM
 */
public class XMLCatalogImpl extends org.eclipse.wsdl.validate.internal.xml.XMLCatalog
{
  protected XMLCatalog xmlCatalog = new XMLCatalog();

  /**
   * @see org.eclipse.wsdl.validate.internal.xml.XMLCatalog#addEntryToCatalog(java.lang.String, java.lang.String)
   */
  public void addEntryToCatalog(String publicId, String systemId)
  {
    DTDLocation resLoc = new DTDLocation();
    resLoc.setLocation(systemId);
    resLoc.setPublicId(publicId);
    xmlCatalog.addEntity(resLoc);
  }

  /**
   * @see org.eclipse.wsdl.validate.internal.xml.XMLCatalog#resolveEntityLocation(java.lang.String, java.lang.String)
   */
  public String resolveEntityLocation(String publicId, String systemId)
  {
    String resolvedId = null;

    try
    {
      InputSource is = xmlCatalog.resolveEntity(publicId, systemId);
      if (is != null)
      {
        resolvedId = is.getSystemId();
      }
    }
    catch (IOException e)
    {
    }
    catch (SAXException e)
    {
    }
    // needs to return null if it can't resolve the id
    if (resolvedId != null && resolvedId.equals(""))
    {
      resolvedId = null;
    }
    return resolvedId;
  }

  /**
   * Add a configured XML Catalog to this catalog.
   * 
   * @param catalog A configured XML catalog to add to this catalog.
   */
  public void addXMLCatalog(XMLCatalog catalog)
  {
    xmlCatalog.addConfiguredXMLCatalog(catalog);
  }

}
