/**
 * <copyright>
 *
 * Copyright (c) 2002-2003 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 *   IBM - Initial API and implementation
 *
 * </copyright>
 */
package org.eclipse.wsdl.validate.ui.eclipse;

import org.eclipse.core.resources.IFile;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.ui.IActionDelegate;
import org.eclipse.validate.ReporterRegister;

/**
 * An action delegate for the WSDL validator.
 * 
 * @author Lawrence Mandel, IBM
 */
public class ValidateWSDLActionDelegate implements IActionDelegate
{
  protected ISelection selection;
  protected void validate(IFile file)
  {
    ValidateWSDLAction validateAction = new ValidateWSDLAction(file, true);
    validateAction.setReporter(ReporterRegister.getInstance().getReporter(Validator.WSDL_VALIDATOR_ID));
    validateAction.run();	
  }
 
  /**
   * @see org.eclipse.ui.IActionDelegate#run(IAction)
   */
  public void run(IAction action)
  {
  	IFile file = null;
    if (!selection.isEmpty() && selection instanceof IStructuredSelection)
    {
      IStructuredSelection structuredSelection = (IStructuredSelection) selection;
      Object element = structuredSelection.getFirstElement();

      if (element instanceof IFile)
      {
        file = (IFile) element;
      }
      else
      {
        return;
      }
    }
          
    if (file != null)
    {          
      validate(file);
    }
  }

  /**
   * @see org.eclipse.ui.IActionDelegate#selectionChanged(IAction, ISelection)
   */
  public void selectionChanged(IAction action, ISelection selection)
  {
  	this.selection = selection;
  }

}
