/**
 * <copyright>
 *
 * Copyright (c) 2002-2003 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 *   IBM - Initial API and implementation
 *
 * </copyright>
 */
package org.eclipse.wsdl.validate.ui.eclipse;

import org.eclipse.core.resources.IFile;
import org.eclipse.validate.IReporter;
import org.eclipse.validate.IValidator;
import org.eclipse.validate.DefaultReporter;

/**
 * The WSDL validator implementation of the validator interface.
 * 
 * @author Lawrence Mandel, IBM
 */
public class Validator implements IValidator
{
  IReporter reporter;
  /**
   * The id of the validator for reporting messages in the tasks view.
   */
  public static final String WSDL_VALIDATOR_ID = "com.ibm.etools.validation.wsdl.WSDLValidator".intern();

  /**
   * Constructor.
   */
  public Validator()
  {
    
  }
  
  /**
   * @see org.eclipse.validate.IValidator#setReporter(org.eclipse.validate.IReporter)
   */
  public void setReporter(IReporter reporter)
  {
  	this.reporter = reporter;
  }

  /**
   * @see org.eclipse.validate.IValidator#validate(org.eclipse.core.resources.IFile)
   */
  public void validate(IFile file)
  {
    ValidateWSDLAction validateAction = new ValidateWSDLAction(file);
    validateAction.setReporter(getReporter());
    validateAction.run();
  }
  
  /**
   * @see org.eclipse.validate.IValidator#getReporter()
   */
  public IReporter getReporter()
  {
    if (reporter == null)
    {
      reporter = new DefaultReporter(WSDL_VALIDATOR_ID);	
    }	
    return reporter;
  }
}
