package org.eclipse.wsdl.validate.ui.internal.eclipse;

import java.text.MessageFormat;
import java.util.List;
import java.util.StringTokenizer;

import org.eclipse.jface.dialogs.Dialog;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.ISelectionChangedListener;
import org.eclipse.jface.viewers.SelectionChangedEvent;
import org.eclipse.jface.viewers.StructuredSelection;
import org.eclipse.swt.SWT;
import org.eclipse.swt.custom.StyleRange;
import org.eclipse.swt.custom.StyledText;
import org.eclipse.swt.events.MouseEvent;
import org.eclipse.swt.events.MouseMoveListener;
import org.eclipse.swt.graphics.Font;
import org.eclipse.swt.graphics.Point;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Text;
import org.eclipse.wsdl.validate.ValidationMessage;


public class ReferencedFileErrorDialog extends Dialog
{
  protected TaskListTableViewer tableViewer;
  protected List errorList;
  protected String markedUpDetailsMessage;
  protected String contextFile;
  protected String referencedFile;
  protected StyledText styledText;
  protected Text fullFileNameField;

  public ReferencedFileErrorDialog(Shell parentShell, List errorList, String contextFile, String referencedFile)
  {
    super(parentShell);

    int styleBits = getShellStyle() | SWT.RESIZE;
    styleBits &= ~SWT.APPLICATION_MODAL;

    setShellStyle(styleBits);
    this.errorList = errorList;

    this.referencedFile = referencedFile;
    this.contextFile = contextFile;
    this.markedUpDetailsMessage = getMarkedUpDetailsMessage();
  }

  public int createAndOpen()
  {
    create();
    getShell().setText("Referenced File Error Details");
    setBlockOnOpen(false);
    return open();
  }


  protected Control createButtonBar(Composite parent)
  {
    Composite composite = new Composite(parent, SWT.NONE);
    composite.setLayout(new GridLayout(2, false));
    composite.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));

    fullFileNameField = new Text(composite, SWT.NONE);
    fullFileNameField.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
    fullFileNameField.setBackground(parent.getBackground());
    fullFileNameField.setEditable(false);

    super.createButtonBar(composite);

    return composite;
  }

  protected Control createDialogArea(Composite parent)
  {
    Composite dialogArea = (Composite) super.createDialogArea(parent);
    dialogArea.setLayout(new GridLayout());

    Composite c = new Composite(dialogArea, SWT.NONE);
    c.setLayout(new GridLayout());
    c.setLayoutData(createGridData(true, -1, 200));

    styledText = new StyledText(c, SWT.MULTI | SWT.WRAP);
    styledText.setBackground(c.getBackground());
    setStyledText(styledText, markedUpDetailsMessage);
    styledText.setEditable(false);
    styledText.setLayoutData(createGridData(false, 650, -1));

    MouseListener mouseListener = new MouseListener();
    styledText.addMouseMoveListener(mouseListener);

    tableViewer = new TaskListTableViewer(c, 10);
    tableViewer.setInput(errorList);
    tableViewer.addSelectionChangedListener(new InternalSelectionListener());
    tableViewer.getControl().setLayoutData(createGridData(true, 700, -1));
    return dialogArea;
  }

  private String getFullURI(int offset)
  {
    String uri = "";
    int index = getIndex(offset);
    if (index != -1)
    {
      if (index == 0 || index == 2 || index == 3)
      {
        uri = referencedFile;
      }
      else
      {
        uri = contextFile;
      }
    }
    return uri;
  }

  private int getIndex(int offset)
  {
    int result = -1;
    StyleRange[] range = styledText.getStyleRanges();
    for (int i = 0; i < range.length; i++)
    {
      int l = range[i].start;
      int r = l + range[i].length;
      if (l <= offset && r >= offset)
      {
        result = i;
        break;
      }
    }
    return result;
  }

  class MouseListener implements MouseMoveListener
  {
    public void mouseMove(MouseEvent event)
    {
      String toolTipText = "";
      try
      {

        int offset = styledText.getOffsetAtLocation(new Point(event.x, event.y));
        toolTipText = getFullURI(offset);

      }
      catch (Exception e)
      {
      }
      styledText.setToolTipText(toolTipText);
      if (toolTipText != null && toolTipText.length() > 0)
      {
        fullFileNameField.setText(toolTipText);
      }
    }
  }

  private String getMarkedUpDetailsMessage()
  {
	String detailsMessage = "";  	
    // TODO... need to move '_UI_REF_FILE_ERROR_DESCRIPTION' to this plugin's properties file
    //			
    //Plugin plugin = (Plugin) Platform.getPlugin("com.ibm.etools.xsdeditor");
    //if (plugin instanceof UIResourcePlugin)
    //{
      //UIResourcePlugin resourcesPlugin = (UIResourcePlugin) plugin;
      //String string = resourcesPlugin.getString("_UI_REF_FILE_ERROR_DESCRIPTION");
      String string = ValidateWSDLPlugin.getInstance().getString("_UI_REF_FILE_ERROR_DESCRIPTION");
      // TODO... need to edit the properties file to remove "'" characters from the string
      // I'm using these characters to markup the bold font. It's safer if I add these programtically.
      //
	  string = removePattern(string, "'");

      String c = "'" + URIHelper.getLastSegment(contextFile) + "'";
      String r = "'" + URIHelper.getLastSegment(referencedFile) + "'";

      detailsMessage = MessageFormat.format(string, new Object[] { r, c, r, c });    
    //}
    return detailsMessage;
  }

  private String removePattern(String string, String pattern)
  {
  	while (true)
  	{
  		int index = string.indexOf(pattern);
  		if (index != -1)
  		{
  			string = string.substring(0, index) + string.substring(index + pattern.length());
  		}
  		else
  		{
  			break;
  		}
  	}
  	return string;  	
  }

  private void setStyledText(StyledText styledText, String text)
  {
    String visibleMessage = "";
    for (StringTokenizer st = new StringTokenizer(markedUpDetailsMessage, "'", false); st.hasMoreTokens();)
    {
      String token = st.nextToken();
      visibleMessage += token;
    }

    styledText.setText(visibleMessage);
    Font font = styledText.getFont();

    boolean inQuote = false;
    int position = 0;
    for (StringTokenizer st = new StringTokenizer(markedUpDetailsMessage, "'", true); st.hasMoreTokens();)
    {
      String token = st.nextToken();

      if (token.equals("'"))
      {
        inQuote = !inQuote;
      }
      else
      {
        if (inQuote)
        {
          try
          {

            StyleRange style = new StyleRange(position, token.length(), styledText.getForeground(), styledText.getBackground(), SWT.BOLD);
            styledText.setStyleRange(style);
          }
          catch (Exception e)
          {
            e.printStackTrace();
          }
        }
        position = position + token.length();
      }
    }
  }

  private static GridData createGridData(boolean fillBoth, int w, int h)
  {
    GridData gd = new GridData(fillBoth ? GridData.FILL_BOTH : GridData.FILL_HORIZONTAL);
    gd.widthHint = w;
    gd.heightHint = h;
    return gd;
  }


  protected class InternalSelectionListener implements ISelectionChangedListener
  {
    public void selectionChanged(SelectionChangedEvent event)
    {
      ISelection selection = event.getSelection();
      if (selection instanceof StructuredSelection)
      {
        ValidationMessage validationMessage = (ValidationMessage) ((StructuredSelection) selection).getFirstElement();
        if (validationMessage != null)
        {
          String uristring = validationMessage.getURI();
          ReferencedFileErrorUtility.openEditorAndGotoError(uristring, validationMessage.getLine(), validationMessage.getColumn());
        }
      }
    }
  }
}


















/*

		Composite c2 = new Composite(c, SWT.NONE);
	GridLayout layout = new GridLayout(4, false);
	layout.marginWidth = 0;
	layout.horizontalSpacing = 0;
	layout.verticalSpacing = 0;
		c2.setLayout(layout);
		c2.setLayoutData(new GridData(GridData.GRAB_HORIZONTAL |  GridData.HORIZONTAL_ALIGN_CENTER));

	Label label1_0 = new Label(c2, SWT.BOLD);
	label1_0.setImage(XMLCommonUIPlugin.getInstance().getImage("icons/XMLFile.gif"));
	
		Label label1 = new Label(c2, SWT.BOLD);
	//label1.setImage(XMLCommonUIPlugin.getInstance().getImage("icons/XMLFile.gif"));
	//label1.setAlignment(SWT.RIGHT);
		label1.setText("Validated File");
	label1.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
	
	Label label1_1 = new Label(c2, SWT.BOLD);		
	label1_1.setText(":");
			
		Text contextFileField = new Text(c2, SWT.NONE);
		contextFileField.setText(contextFile);
		contextFileField.setBackground(c2.getBackground());

	Label labe2_0 = new Label(c2, SWT.BOLD);
	labe2_0.setImage(XMLCommonUIPlugin.getInstance().getImage("icons/XMLFile.gif"));
		
		Label label2 = new Label(c2, SWT.BOLD);
	//label2.setAlignment(SWT.RIGHT);
		label2.setText("Referenced File");
		label2.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));

	Label label2_1 = new Label(c2, SWT.BOLD);		
	label2_1.setText(":");
		
		Text referencedFileField = new Text(c2, SWT.NONE);
		referencedFileField.setText(referencedFile);
		referencedFileField.setBackground(c2.getBackground());
*/