package org.eclipse.wsdl.validate.ui.internal.eclipse;

import java.net.URL;

import org.eclipse.core.resources.IFile;
import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.core.runtime.IPath;
import org.eclipse.core.runtime.Path;
import org.eclipse.jface.text.BadLocationException;
import org.eclipse.jface.text.IDocument;
import org.eclipse.swt.widgets.Display;
import org.eclipse.ui.IEditorPart;
import org.eclipse.ui.IWorkbench;
import org.eclipse.ui.IWorkbenchWindow;
import org.eclipse.ui.PartInitException;
import org.eclipse.ui.editors.text.TextEditor;
import org.eclipse.ui.part.FileEditorInput;
import org.eclipse.ui.texteditor.IDocumentProvider;

public class ReferencedFileErrorUtility
{
  public static void openEditorAndGotoError(String uristring, final int line, final int column)
  {
    if (uristring != null)
    {
      try
      {
        URL uri = new URL(uristring);
        if (uri != null)
        {
          if ("file".equals(uri.getProtocol()))
          {
            String pathString = uri.getPath();
            IPath path = new Path(pathString);
            String device = path.getDevice();
            if (device != null && device.startsWith("/"))
            {
              path = path.setDevice(device.substring(1));
            }
            IFile file = ResourcesPlugin.getWorkspace().getRoot().getFileForLocation(path);
            if (file != null && file.exists())
            {
              //WorkbenchUtility.openEditor(file);
              // Open the editor for this file.
              final IFile iFile = file;
              IWorkbench workbench = ValidateWSDLPlugin.getInstance().getWorkbench();
              final IWorkbenchWindow workbenchWindow = workbench.getActiveWorkbenchWindow();

              Display.getDefault().asyncExec
              (new Runnable()
              {
                public void run()
                {
                  try
                  {
                    workbenchWindow.getActivePage().openEditor(new FileEditorInput(iFile), ValidateWSDLPlugin.getInstance().getWorkbench().getEditorRegistry().getDefaultEditor(iFile.getName()).getId());
                  }
                  catch (PartInitException ex)
                  {
                    //LoggerFactory.getLoggerInstance().logError("Exception encountered when attempting to open file: " + iFile + "\n\n", ex);
                  	//B2BGUIPlugin.getPlugin().getMsgLogger().write("Exception encountered when attempting to open file: " + iFile + "\n\n" + ex);
                  }
                }
              });
                
              Runnable runnable = new Runnable()
              {
                public void run()
                {
                  //IEditorPart editorPart = WorkbenchUtility.getActiveEditor();
                  IEditorPart editorPart = ValidateWSDLPlugin.getInstance().getWorkbench().getActiveWorkbenchWindow().getActivePage().getActiveEditor();
                  gotoError(editorPart, line, column);
                }
              };
              Display.getCurrent().asyncExec(runnable);
            }
          }
        }
      }
      catch (Exception e)
      {
      }
    }
  }

  private static void gotoError(IEditorPart editorPart, int line, int column)
  {
    if (editorPart != null)
    {
      TextEditor textEditor = (TextEditor) editorPart.getAdapter(TextEditor.class);
      if (textEditor != null)
      {
        try
        {
          IDocumentProvider dp = textEditor.getDocumentProvider();
          IDocument document = (dp != null) ? dp.getDocument(textEditor.getEditorInput()) : null;
          textEditor.selectAndReveal(document.getLineOffset(line - 1) + column - 1, 0);
        }
        catch (BadLocationException x)
        {
          // marker refers to invalid text position -> do nothing
        }
      }
    }
  }
}