/**
 * <copyright>
 *
 * Copyright (c) 2002-2003 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 *   IBM - Initial API and implementation
 *
 * </copyright>
 */
package org.wsi.test.document.impl;

import org.wsi.test.analyzer.config.AnalyzerConfig;
import org.wsi.test.analyzer.config.AnalyzerConfigReader;
import org.wsi.test.analyzer.config.impl.AnalyzerConfigImpl;
import org.wsi.test.analyzer.config.impl.AnalyzerConfigReaderImpl;
import org.wsi.test.document.DocumentFactory;
import org.wsi.test.log.Log;
import org.wsi.test.log.LogReader;
import org.wsi.test.log.LogWriter;
import org.wsi.test.log.impl.LogImpl;
import org.wsi.test.log.impl.LogReaderImpl;
import org.wsi.test.log.impl.LogWriterImpl;
import org.wsi.test.monitor.config.MonitorConfig;
import org.wsi.test.monitor.config.MonitorConfigReader;
import org.wsi.test.monitor.config.impl.MonitorConfigImpl;
import org.wsi.test.monitor.config.impl.MonitorConfigReaderImpl;
import org.wsi.test.profile.ProfileAssertions;
import org.wsi.test.profile.ProfileAssertionsReader;
import org.wsi.test.profile.impl.ProfileAssertionsImpl;
import org.wsi.test.profile.impl.ProfileAssertionsReaderImpl;
import org.wsi.test.report.Report;
import org.wsi.test.report.ReportWriter;
import org.wsi.test.report.impl.ReportImpl;
import org.wsi.test.report.impl.ReportWriterImpl;
import org.wsi.util.WSIProperties;

/**
 * This is the implementation of the Conformance document factory which provides access to
 * implementations of the documents, readers and writers. 
 * 
 * @version 1.0.1
 * @author Peter Brittenham (peterbr@us.ibm.com)
 */
public class DocumentFactoryImpl extends DocumentFactory
{
  /**
   * Document factory implementation.
   */
  public DocumentFactoryImpl()
  {
  }

  /**
   * Create log file.
   */
  public Log newLog()
  {
    return new LogImpl();
  }

  /**
   * Create monitor config.
   */
  public MonitorConfig newMonitorConfig()
  {
    return new MonitorConfigImpl();
  }

  /**
   * Create analyzer config.
   */
  public AnalyzerConfig newAnalyzerConfig()
  {
    return new AnalyzerConfigImpl();
  }

  /**
   * Create profile assertions.
   */
  public ProfileAssertions newProfileAssertions()
  {
    return new ProfileAssertionsImpl();
  }

  /**
   * Create report.
   */
  public Report newReport()
  {
    return new ReportImpl();
  }

  /**
   * Create monitor config reader.
   */
  public MonitorConfigReader newMonitorConfigReader()
  {
    return new MonitorConfigReaderImpl();
  }

  /**
   * Create analyzer config reader.
   */
  public AnalyzerConfigReader newAnalyzerConfigReader()
  {
    return new AnalyzerConfigReaderImpl();
  }

  /**
   * Create profile assertions reader.
   */
  public ProfileAssertionsReader newProfileAssertionsReader()
  {
    // Return implementation
    return new ProfileAssertionsReaderImpl();
  }

  /**
   * Create log reader.
   */
  public LogReader newLogReader()
  {
    // Return implementation
    return new LogReaderImpl();
  }

  // WRITERS

  /**
   * Create log writer.
   */
  public LogWriter newLogWriter()
  {
    return new LogWriterImpl();
  }

  /**
   * Create a new instance of a DocumentReader.
   */
  public ReportWriter newReportWriter()
  {
    // Return implementation
    return new ReportWriterImpl();
  }

  /**
   * Find the factory class name which can be specified as a Java property.
   */
  private static String getFactoryClassName()
  {
    // Get property value
    return WSIProperties.getProperty(
      WSIProperties.PROP_DOCUMENT_FACTORY,
      WSIProperties.DEF_DOCUMENT_FACTORY);
  }
}
