/**
 * <copyright>
 *
 * Copyright (c) 2002-2003 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 *   IBM - Initial API and implementation
 *
 * </copyright>
 */
package org.wsi.test.profile.impl;

import java.util.Vector;

import org.wsi.test.profile.ProfileArtifact;
import org.wsi.test.profile.Profile;
import org.wsi.test.profile.ProfileAssertions;
import org.wsi.test.profile.TestAssertion;

import java.util.Iterator;
import java.util.TreeMap;

/**
 * This class ...
 * 
 * @version 1.0.1
 * @author Peter Brittenham  (peterbr@us.ibm.com)
 */
public class ProfileAssertionsImpl implements ProfileAssertions
{
  /**
   * Location of the profile definition.
   */
  protected String documentURI;

  /**
   * Name of the profile test assertion document.
   */
  protected String documentName;

  /**
   * Version of the profile test assertion document.
   */
  protected String documentVersion;

  // ADD: A profile definition should also have a description.

  /**
   * List of profiles.
   */
  Vector profileList = new Vector();

  /**
   * List of artifacts.
   */
  TreeMap artifactList = new TreeMap();

  /* (non-Javadoc)
   * @see org.wsi.test.profile.ProfileAssertions#getProfileList()
   */
  public Vector getProfileList()
  {
    return this.profileList;
  }

  /* (non-Javadoc)
   * @see org.wsi.test.profile.ProfileAssertions#setProfileList(Vector)
   */
  public void setProfileList(Vector profileList)
  {
    this.profileList = profileList;
  }

  /* (non-Javadoc)
   * @see org.wsi.test.profile.ProfileAssertions#addProfile(Profile)
   */
  public void addProfile(Profile profile)
  {
    this.profileList.add(profile);
  }

  /* (non-Javadoc)
   * @see org.wsi.test.profile.ProfileAssertions#getArtifactList()
   */
  public TreeMap getArtifactList()
  {
    return this.artifactList;
  }

  /* (non-Javadoc)
   * @see org.wsi.test.profile.ProfileAssertions#getArtifact(java.lang.String)
   */
  public ProfileArtifact getArtifact(String type)
  {
    return (ProfileArtifact) this.artifactList.get(type);
  }

  /* (non-Javadoc)
   * @see org.wsi.test.profile.ProfileAssertions#setArtifactList(TreeMap)
   */
  public void setArtifactList(TreeMap artifactList)
  {
    this.artifactList = artifactList;
  }

  /* (non-Javadoc)
   * @see org.wsi.test.profile.ProfileAssertions#addArtifact(ReportArtifact)
   */
  public void addArtifact(ProfileArtifact artifact)
  {
    this.artifactList.put(artifact.getType(), artifact);
  }

  /* (non-Javadoc)
   * @see org.wsi.test.profile.ProfileAssertions#getTestAssertion(String)
   */
  public TestAssertion getTestAssertion(String id)
  {
    TestAssertion testAssertion = null;

    // Go through the list of artifacts and find the test assertion 
    Iterator iterator = artifactList.values().iterator();
    while ((iterator.hasNext()) && (testAssertion == null))
    {
      testAssertion = ((ProfileArtifact) iterator.next()).getTestAssertion(id);
    }

    return testAssertion;
  }

  /* (non-Javadoc)
   * @see org.wsi.test.profile.ProfileAssertions#createArtifact()
   */
  public ProfileArtifact createArtifact()
  {
    return new ProfileArtifactImpl();
  }

  /* (non-Javadoc)
   * @see org.wsi.test.document.WSIDocument#getLocation()
   */
  public String getLocation()
  {
    return this.documentURI;
  }

  /* (non-Javadoc)
   * @see org.wsi.test.document.WSIDocument#setLocation(String)
   */
  public void setLocation(String documentURI)
  {
    this.documentURI = documentURI;
  }

  /**
   * @see org.wsi.test.profile.ProfileAssertions#getTADName()
   */
  public String getTADName()
  {
    return this.documentName;
  }

  /**
   * @see org.wsi.test.profile.ProfileAssertions#setTADName(String)
   */
  public void setTADName(String documentName)
  {
    this.documentName = documentName;
  }

  /**
   * @see org.wsi.test.profile.ProfileAssertions#getTADVersion()
   */
  public String getTADVersion()
  {
    return this.documentVersion;
  }

  /**
   * @see org.wsi.test.profile.ProfileAssertions#setTADVersion(String)
   */
  public void setTADVersion(String documentVersion)
  {
    this.documentVersion = documentVersion;
  }

  /* (non-Javadoc)
   * @see org.wsi.test.document.DocumentElement#toXMLString(String)
   */
  public String toXMLString(String namespaceName)
  {
    return null;
  }
}
