/**
 * <copyright>
 *
 * Copyright (c) 2002-2003 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 *   IBM - Initial API and implementation
 *
 * </copyright>
 */
package org.wsi.test.profile.validator;

import org.wsi.WSIException;
import org.wsi.test.analyzer.AnalyzerContext;
import org.wsi.test.profile.ProfileArtifact;
import org.wsi.test.report.ReportArtifact;
import org.wsi.test.report.Reporter;
import org.wsi.wsdl.WSDLDocument;

/**
 * Interface definition for message validation test procedure.
 *
 * @version 1.0.1
 * @author Peter Brittenham
 * @author Graham Turrell (gturrell@uk.ibm.com)
 */
public interface MessageValidator extends BaseValidator
{
  /**
   * HTTP 1.0 version indicator.
   */
  public static final String HTTP_VERSION_1_0 = "HTTP/1.0";

  /**
   * HTTP 1.1 version indicator.
   */
  public static final String HTTP_VERSION_1_1 = "HTTP/1.1";

  /**
   * HTTP POST message indicator.
   */
  public static final String HTTP_POST = "POST";

  /**
   * Initiailize validation test procedure.
   * @param analyzerContext the analyzerContext.
   * @param artifact        an profile artifact.
   * @param reportArtifact  the report artifact.
   * @param wsdlDocument the Web service definition
   * @param reporter the reporter which is used to add errors to the conformance report
   * @throws WSIException if message validator could not be initialized.
   */
  public void init(
    AnalyzerContext analyzerContext,
    ProfileArtifact artifact,
    ReportArtifact reportArtifact,
    WSDLDocument wsdlDocument,
    Reporter reporter)
    throws WSIException;

  /**
   * Validate the message located by the log entry. 
   * @param entryContext a log entry locating a message.
   * @throws WSIException if an unexpected error occurred while 
   *         processing the log entry.
   */
  public void validate(EntryContext entryContext) throws WSIException;
}
