/**
 * <copyright>
 *
 * Copyright (c) 2002-2003 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 *   IBM - Initial API and implementation
 *
 * </copyright>
 */
package org.wsi.test.profile.validator;

import org.wsi.WSIException;
import org.wsi.test.analyzer.AnalyzerContext;
import org.wsi.test.profile.ProfileArtifact;
import org.wsi.test.report.ReportArtifact;
import org.wsi.test.report.Reporter;
import org.wsi.wsdl.WSDLDocument;

/**
 * The WSDL validator will verify that the WSDL and associated XML schema definitions
 * are in conformance with the profile.
 *
 * @version 1.0.1
 * @author Peter Brittenham
 */
public interface WSDLValidator extends BaseValidator
{
  /**
   * Initiailize validation test procedure.
   * @param analyzerContext the analyzerContext.
   * @param artifact        the profile artifact.
   * @param reportArtifact  the report artifact.
   * @param wsdlURL         the WSDL document location.
   * @param wsdlDocument    the WSDL document.
   * @param reporter        a Reporter object.
   * @throws WSIException if WSDL validator could not be initialized.
   */
  public void init(
    AnalyzerContext analyzerContext,
    ProfileArtifact artifact,
    ReportArtifact reportArtifact,
    String wsdlURL,
    WSDLDocument wsdlDocument,
    Reporter reporter)
    throws WSIException;

  /**
   * Validate the WSDL based service description.
   * @return the WSDL document.
   * @throws WSIException if an unexpected error occurred
   *         while validating he WSDL based service description.
   */
  public WSDLDocument validate() throws WSIException;
}
