/**
 * <copyright>
 *
 * Copyright (c) 2002-2003 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 *   IBM - Initial API and implementation
 *
 * </copyright>
 */
package org.wsi.test.profile.validator.impl;

import org.wsi.WSIException;
import org.wsi.test.profile.validator.EnvelopeValidator;
import org.wsi.test.profile.validator.MessageValidator;
import org.wsi.test.profile.validator.ProfileValidatorFactory;
import org.wsi.test.profile.validator.WSDLValidator;
import org.wsi.test.profile.validator.UDDIValidator;
import org.wsi.test.profile.validator.impl.envelope.EnvelopeValidatorImpl;
import org.wsi.test.profile.validator.impl.message.MessageValidatorImpl;
import org.wsi.test.profile.validator.impl.uddi.UDDIValidatorImpl;
import org.wsi.test.profile.validator.impl.wsdl.WSDLValidatorImpl;

/**
 * This class is an implementation of the WSILDocumentFactory.
 *
 * @version 1.0.1
 * @author: Peter Brittenham
 */
public class ProfileValidatorFactoryImpl extends ProfileValidatorFactory
{
  /* (non-Javadoc)
   * @see org.wsi.test.profile.validator.ProfileValidatorFactory#newUDDIValidator()
   */
  public UDDIValidator newUDDIValidator() throws WSIException
  {
    // Create new UDDI validator 
    UDDIValidator uddiValidator = new UDDIValidatorImpl();
    // Return validator
    return uddiValidator;
  }
  /* (non-Javadoc)
   * @see org.wsi.test.profile.validator.ProfileValidatorFactory#newWSDLValidator()
   */
  public WSDLValidator newWSDLValidator() throws WSIException
  {
    // Create new WSDL validator 
    WSDLValidator wsdlValidator = new WSDLValidatorImpl();

    // Return validator
    return wsdlValidator;
  }

  /* (non-Javadoc)
   * @see org.wsi.test.profile.validator.ProfileValidatorFactory#newMessageValidator()
   */
  public MessageValidator newMessageValidator() throws WSIException
  {
    // Create new message validator 
    MessageValidator messageValidator = new MessageValidatorImpl();
    // Return validator
    return messageValidator;
  }

  /* (non-Javadoc)
   * @see org.wsi.test.profile.validator.ProfileValidatorFactory#newEnvelopeValidator()
   */
  public EnvelopeValidator newEnvelopeValidator() throws WSIException
  {
    // Create new envelope validator 
    EnvelopeValidator envelopeValidator = new EnvelopeValidatorImpl();
    // Return validator
    return envelopeValidator;
  }
}